@@ -47,7 +47,7 @@ typedef struct {
   int clustering_method;
 } opts_t;
 
-static char* usestr =
+static const char usestr[] =
 "    -C k - generate no more than k clusters (0)\n\
        0 : no limit\n\
     -c k - use clustering method k (0)\n\
@@ -61,25 +61,19 @@ static void usage(char* cmd, int eval)
 {
     fprintf(stderr, "Usage: %s <options> graphfile\n", cmd);
     fputs (usestr, stderr);
-    exit(eval);
+    graphviz_exit(eval);
 }
 
-static FILE *openFile(char *name, char *mode, char* cmd)
+static FILE *openFile(const char *name, const char* cmd)
 {
     FILE *fp;
-    char *modestr;
 
-    fp = fopen(name, mode);
+    fp = fopen(name, "w");
     if (!fp) {
-	if (*mode == 'r')
-	    modestr = "reading";
-	else
-	    modestr = "writing";
-	fprintf(stderr, "%s: could not open file %s for %s\n",
-		cmd, name, modestr);
-	exit(-1);
+	fprintf(stderr, "%s: could not open file %s for writing\n", cmd, name);
+	graphviz_exit(-1);
     }
-    return (fp);
+    return fp;
 }
 
 static void init(int argc, char *argv[], opts_t* opts) {
@@ -95,19 +89,19 @@ static void init(int argc, char *argv[], opts_t* opts) {
   while ((c = getopt(argc, argv, ":vC:c:o:?")) != -1) {
     switch (c) {
     case 'c':
-      if ((sscanf(optarg,"%d", &v) == 0) || (v < 0)) {
+      if (sscanf(optarg, "%d", &v) == 0 || v < 0) {
 	usage(cmd,1);
       }
       else opts->clustering_method = v;
       break;
     case 'C':
-      if ((sscanf(optarg,"%d",&v) == 0) || (v < 0)) {
+      if (sscanf(optarg, "%d", &v) == 0 || v < 0) {
 	usage(cmd,1);
       }
       else opts->maxcluster = v;
       break;
     case 'o':
-      opts->outfp = openFile(optarg, "w", cmd);
+      opts->outfp = openFile(optarg, cmd);
       break;
     case 'v':
       Verbose = 1;
@@ -134,14 +128,12 @@ static void init(int argc, char *argv[], opts_t* opts) {
 
 static Agraph_t *gread(FILE * fp)
 {
-    return agread(fp, (Agdisc_t *) 0);
+    return agread(fp, NULL);
 }
 
-void clusterGraph (Agraph_t* g, int maxcluster, int clustering_method){
+static void clusterGraph (Agraph_t* g, int maxcluster, int clustering_method){
   initDotIO(g);
   attached_clustering(g, maxcluster, clustering_method);
-  return;
-
 }
 
 int main(int argc, char *argv[])
@@ -161,5 +153,5 @@ int main(int argc, char *argv[])
     prevg = g;
   }
 
-  return 0; 
+  graphviz_exit(0);
 }
