@@ -17,49 +17,44 @@
 
 
 #include "config.h"
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#else
-#include <ast/compat_unistd.h>
-#endif
-
-
+#include <limits.h>
+#include <stddef.h>
+#include <stdio.h>
 
 #include <cgraph/cgraph.h>
 #include <cgraph/exit.h>
 #include <gvpr/gvpr.h>
 
 #ifdef DEBUG
-#include <sfio/sfio.h>
 static ssize_t outfn (void* sp, const char *buf, size_t nbyte, void* dp)
 {
-    write (1, "<stdout> ", 8);
-    return write (1, buf, nbyte);
+  if (nbyte > (size_t)INT_MAX) {
+    return -1;
+  }
+  return printf("<stdout>%.*s", (int)nbyte, buf);
 }
 
 static ssize_t errfn (void* sp, const char *buf, size_t nbyte, void* dp)
 {
-    write (2, "<stderr> ", 8);
-    return write (2, buf, nbyte);
+  if (nbyte > (size_t)INT_MAX) {
+    return -1;
+  }
+  return fprintf(stderr, "<stderr>%.*s", (int)nbyte, buf);
 }
 
 static int iofread(void *chan, char *buf, int bufsize)
 {
-    return read(sffileno(chan), buf, bufsize);
-}
-
-static int ioputstr(void *chan, const char *str)
-{
-    return sfputr(chan, str, -1);
+  return (int)fread(buf, 1, (size_t)bufsize, chan);
 }
 
 static int ioflush(void *chan)
 {
-    return sfsync(chan);
+  return fflush(chan);
 }
 
-static Agiodisc_t gprIoDisc = { iofread, ioputstr, ioflush };
+typedef int (*printfn)(void *chan, const char *format, ...);
+
+static Agiodisc_t gprIoDisc = { iofread, (printfn)fprintf, ioflush };
 
 static Agdisc_t gprDisc = { &AgMemDisc, &AgIdDisc, &gprIoDisc };
 
@@ -67,7 +62,7 @@ int
 main (int argc, char* argv[])
 {
     Agraph_t* gs[2];
-    Agraph_t* g = agread (sfstdin, &gprDisc);
+    Agraph_t* g = agread(stdin, &gprDisc);
     int rv;
     gvpropts opts;
 
@@ -81,9 +76,7 @@ main (int argc, char* argv[])
     
     rv = gvpr (argc, argv, &opts);
 
-    sfprintf (sfstderr, "rv %d\n", rv);
-    /* for (i = 0; i < opts.n_outgraphs; i++) */
-	/* agwrite (opts.outgraphs[i], sfstdout); */
+    fprintf(stderr, "rv %d\n", rv);
 
     rv = gvpr (argc, argv, &opts);
 
@@ -106,3 +99,7 @@ main (int argc, char* argv[])
 
 #endif
 
+/**
+ * @dir cmd/gvpr
+ * @brief graph pattern scanning and processing language
+ */
