@@ -8,28 +8,10 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GLMOTION_H
-#define GLMOTION_H
+#pragma once
 
 #include "viewport.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#if 0
-    void glmotion_main(ViewInfo * v, GdkEventMotion * event,
-		       GtkWidget * widget);
-    void glmotion_rotate(ViewInfo * v);
-    void glmotion_adjust_pan(ViewInfo * v, float panx, float pany);
-    void graph_zoom(float real_zoom);
-#endif
-
-    void glmotion_zoom(ViewInfo * v);
+    void glmotion_zoom(void);
     void glmotion_pan(ViewInfo * v);
     void glmotion_zoom_inc(int zoomin);
-
-#ifdef __cplusplus
-}				/* end extern "C" */
-#endif
-#endif
