@@ -114,8 +114,7 @@ void switch2D3D(glCompObj *obj, GLfloat x, GLfloat y,
 	    view->active_camera = -1;	/*set to camera */
 	    glCompButtonShow(to3DBtn);
 	    glCompButtonHide(to2DBtn);
-	    panBtn->common.callbacks.click((glCompObj*)panBtn, (GLfloat) 0,
-					   (GLfloat) 0,
+	    panBtn->common.callbacks.click((glCompObj*)panBtn, 0.0f, 0.0f,
 					   (glMouseButtonType) 0);
 	    img3D->common.visible = 0;
 
@@ -257,8 +256,7 @@ glCompSet *glcreate_gl_topview_menu(void)
     b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
     glCompButtonAddPngGlyph(b, smyrnaPath("details.png"));
     b->common.callbacks.click = attrList;
-    copy_glcomp_color(&c, &b->common.color);
-
+    b->common.color = c;
 	
     y = y + off;
 	
@@ -266,14 +264,14 @@ glCompSet *glcreate_gl_topview_menu(void)
     glCompButtonAddPngGlyph(b, smyrnaPath("zoomin.png"));
     b->groupid = 0;
     b->common.callbacks.click = menu_click_zoom_plus;
-    copy_glcomp_color(&c, &b->common.color);
+    b->common.color = c;
     y = y + off;
 
 
     b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
     glCompButtonAddPngGlyph(b, smyrnaPath("zoomout.png"));
     b->common.callbacks.click = menu_click_zoom_minus;
-    copy_glcomp_color(&c, &b->common.color);
+    b->common.color = c;
 
     y = y + off;
 
@@ -281,18 +279,7 @@ glCompSet *glcreate_gl_topview_menu(void)
     b = glCompButtonNew((glCompObj *) p, 1, y, 42, 42, "");
     glCompButtonAddPngGlyph(b, smyrnaPath("center.png"));
     b->common.callbacks.click = menu_click_center;
-    copy_glcomp_color(&c, &b->common.color);
-
-
-
-	
-	
-
-
-
-
-
-
+    b->common.color = c;
 
     p = glCompPanelNew((glCompObj *) s, -250, 550, 150, 175);
     p->common.borderWidth = 0;
