@@ -8,21 +8,12 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef SELECTIONFUNCS_H
-#define SELECTIONFUNCS_H
+#pragma once
 
 #include "draw.h"
-#include <GL/gl.h>
-
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include <glcomp/opengl.h>
 
 extern void pick_objects_rect(Agraph_t* g) ;
 extern void deselect_all(Agraph_t* g);
 extern void add_selpoly(Agraph_t* g,glCompPoly* selPoly,glCompPoint pt);
 extern void clear_selpoly(glCompPoly* sp);
-#ifdef __cplusplus
-}				/* end extern "C" */
-#endif
-#endif
