@@ -1,5 +1,7 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
+/**
+ * @file
+ * @brief connected components filter for graphs
+ */
 
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
@@ -8,7 +10,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -17,14 +19,17 @@
  * Updated by Emden Gansner
  */
 
-#include "config.h"
-
 #include <ctype.h>
+#include <stdbool.h>
+#include <stdio.h>
 #include <stdlib.h>
-#include "cgraph.h"
+#include <cgraph/alloc.h>
+#include <cgraph/cgraph.h>
+#include <cgraph/stack.h>
+#include <cgraph/unreachable.h>
+#include <cgraph/exit.h>
 
-#define N_NEW(n,t)       (t*)calloc((n),sizeof(t))
-#define NEW(t)           (t*)malloc(sizeof(t))
+#define N_NEW(n,t) gv_calloc((n), sizeof(t))
 
 typedef struct {
     Agrec_t h;
@@ -46,11 +51,8 @@ typedef struct {
 
 #include <getopt.h>
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 #include <string.h>
-#include "ingraphs.h"
+#include <ingraphs/ingraphs.h>
 
   /* internals of libgraph */
 #define TAG_NODE            1
@@ -65,24 +67,24 @@ typedef struct {
 #define BY_INDEX 1
 #define BY_SIZE  2
 
-char* Cmd;
-char **Files;
-int verbose;
-int printMode = INTERNAL;
-int useClusters = 0;
-int doEdges = 1;		/* induce edges */
-int doAll = 1;			/* induce subgraphs */
-char *suffix = 0;
-char *outfile = 0;
-char *path = 0;
-int sufcnt = 0;
-int sorted = 0;
-int sortIndex = 0;
-int sortFinal;
-int x_index = -1;
-int x_final = -1;  /* require 0 <= x_index <= x_final or x_final= -1 */ 
-int x_mode;
-char *x_node;
+static char* Cmd;
+static char **Files;
+static int verbose;
+static int printMode = INTERNAL;
+static int useClusters = 0;
+static int doEdges = 1; // induce edges
+static int doAll = 1; // induce subgraphs
+static char *suffix = 0;
+static char *outfile = 0;
+static char *path = 0;
+static int sufcnt = 0;
+static int sorted = 0;
+static int sortIndex = 0;
+static int sortFinal;
+static int x_index = -1;
+static int x_final = -1; // require 0 <= x_index <= x_final or x_final= -1
+static int x_mode;
+static char *x_node;
 
 static char *useString =
     "Usage: ccomps [-svenCx?] [-X[#%]s[-f]] [-o<out template>] <files>\n\
@@ -101,23 +103,19 @@ If no files are specified, stdin is used\n";
 static void usage(int v)
 {
     printf("%s",useString);
-    exit(v);
+    graphviz_exit(v);
 }
 
-static void split(char *name)
-{
+static void split(void) {
     char *sfx = 0;
-    int size;
 
-    sfx = strrchr(name, '.');
+    sfx = strrchr(outfile, '.');
     if (sfx) {
 	suffix = sfx + 1;
-	size = sfx - name;
-	path = (char *) malloc(size + 1);
-	strncpy(path, name, size);
-	*(path + size) = '\0';
+	size_t size = (size_t)(sfx - outfile);
+	path = gv_strndup(outfile, size);
     } else {
-	path = name;
+	path = outfile;
     }
 }
 
@@ -126,7 +124,7 @@ static void split(char *name)
  */
 static int isCluster(Agraph_t * g)
 {
-    return (strncmp(agnameof(g), "cluster", 7) == 0);
+    return strncmp(agnameof(g), "cluster", 7) == 0;
 }
 
 static void init(int argc, char *argv[])
@@ -136,11 +134,11 @@ static void init(int argc, char *argv[])
 
     Cmd = argv[0];
     opterr = 0;
-    while ((c = getopt(argc, argv, ":zo:xCX:nesv")) != -1) {
+    while ((c = getopt(argc, argv, ":zo:xCX:nesv?")) != -1) {
 	switch (c) {
 	case 'o':
 	    outfile = optarg;
-	    split(outfile);
+	    split();
 	    break;
 	case 'C':
 	    useClusters = 1;
@@ -158,16 +156,16 @@ static void init(int argc, char *argv[])
 	    printMode = SILENT;
 	    break;
 	case 'X':
-	    if ((*optarg == '#') || (*optarg == '%')) {
+	    if (*optarg == '#' || *optarg == '%') {
 		char *p = optarg + 1;
 		if (*optarg == '#') x_mode = BY_INDEX;
 		else x_mode = BY_SIZE;
-		if (isdigit(*p)) {
+		if (isdigit((int)*p)) {
 		    x_index = (int)strtol (p, &endp, 10);
 		    printMode = EXTRACT;
 		    if (*endp == '-') {
 			p = endp + 1;
-			if (isdigit(*p)) {
+			if (isdigit((int)*p)) {
 			    x_final = atoi (p);
 			    if (x_final < x_index) {
 				printMode = INTERNAL;
@@ -205,19 +203,23 @@ static void init(int argc, char *argv[])
 		"ccomps: option -%c missing argument - ignored\n", optopt);
 	    break;
 	case '?':
-	    if (optopt == '?')
+	    if (optopt == '\0' || optopt == '?')
 		usage(0);
-	    else
+	    else {
 		fprintf(stderr,
-			"ccomps: option -%c unrecognized - ignored\n", optopt);
+			"ccomps: option -%c unrecognized\n", optopt);
+                usage(1);
+	    }
 	    break;
+	default:
+	    UNREACHABLE();
 	}
     }
     argv += optind;
     argc -= optind;
 
     if (sorted) {
-	if ((printMode == EXTRACT) && (x_index >= 0)) {
+	if (printMode == EXTRACT && x_index >= 0) {
 	    printMode = INTERNAL;
 	    sortIndex = x_index;
 	    sortFinal = x_final;
@@ -233,71 +235,20 @@ static void init(int argc, char *argv[])
 	Files = argv;
 }
 
-typedef struct blk_t {
-    Agnode_t **data;
-    Agnode_t **endp;
-    struct blk_t *prev;
-    struct blk_t *next;
-} blk_t;
-
-typedef struct {
-    blk_t *fstblk;
-    blk_t *curblk;
-    Agnode_t **curp;
-} stk_t;
-
-
-#define SMALLBUF 1024
-#define BIGBUF 1000000
-
-static Agnode_t *base[SMALLBUF];
-static blk_t Blk;
-static stk_t Stk;
-
-static void initStk(void)
-{
-    Blk.data = base;
-    Blk.endp = Blk.data + SMALLBUF;
-    Stk.curblk = Stk.fstblk = &Blk;
-    Stk.curp = Stk.curblk->data;
-}
+static gv_stack_t Stk;
 
 static void push(Agnode_t * np)
 {
-    if (Stk.curp == Stk.curblk->endp) {
-	if (Stk.curblk->next == NULL) {
-	    blk_t *bp = NEW(blk_t);
-	    if (bp == 0) {
-		fprintf(stderr, "gc: Out of memory\n");
-		exit(1);
-	    }
-	    bp->prev = Stk.curblk;
-	    bp->next = NULL;
-	    bp->data = N_NEW(BIGBUF, Agnode_t *);
-	    if (bp->data == 0) {
-		fprintf(stderr, "%s: Out of memory\n", Cmd);
-		exit(1);
-	    }
-	    bp->endp = bp->data + BIGBUF;
-	    Stk.curblk->next = bp;
-	}
-	Stk.curblk = Stk.curblk->next;
-	Stk.curp = Stk.curblk->data;
-    }
-    ND_mark(np) = -1;
-    *Stk.curp++ = np;
+  ND_mark(np) = -1;
+  stack_push_or_exit(&Stk, np);
 }
 
 static Agnode_t *pop(void)
 {
-    if (Stk.curp == Stk.curblk->data) {
-	if (Stk.curblk == Stk.fstblk)
-	    return 0;
-	Stk.curblk = Stk.curblk->prev;
-	Stk.curp = Stk.curblk->endp;
-    }
-    Stk.curp--;
-    return *Stk.curp;
+  if (stack_is_empty(&Stk)) {
+    return NULL;
+  }
+  return stack_pop(&Stk);
 }
 
 static int dfs(Agraph_t * g, Agnode_t * n, Agraph_t * out)
@@ -351,7 +302,7 @@ static char *getName(void)
 	name = outfile;
     else {
 	if (!buf)
-	    buf = (char *) malloc(strlen(outfile) + 20);	/* enough to handle '_number' */
+	    buf = gv_alloc(strlen(outfile) + 20); // enough to handle '_number'
 	if (suffix)
 	    sprintf(buf, "%s_%d.%s", path, sufcnt, suffix);
 	else
@@ -378,32 +329,10 @@ static void gwrite(Agraph_t * g)
 	    perror("ccomps");
 	}
 	agwrite(g, outf);
-	fflush(outf);
 	fclose(outf);
     }
 }
 
-/* getBuf
- * Return pointer to buffer containing at least n bytes.
- * Non-reentrant.
- */
-static char *getBuf(int n)
-{
-    static int len = 0;
-    static char *buf = 0;
-    int sz;
-
-    if (n > len) {
-	sz = n + 100;
-	if (len == 0)
-	    buf = (char *) malloc(sz);
-	else
-	    buf = (char *) realloc(buf, sz);
-	len = sz;
-    }
-    return buf;
-}
-
 /* projectG:
  * If any nodes of subg are in g, create a subgraph of g
  * and fill it with all nodes of subg in g and their induced
@@ -480,7 +409,7 @@ static void deriveClusters(Agraph_t* dg, Agraph_t * g)
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
 	if (!strncmp(agnameof(subg), "cluster", 7)) {
 	    dn = agnode(dg, agnameof(subg), 1);
-	    agbindrec (dn, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
+	    agbindrec (dn, "nodeinfo", sizeof(Agnodeinfo_t), true);
 	    ND_ptr(dn) = (Agobj_t*)subg;
 	    for (n = agfstnode(subg); n; n = agnxtnode(subg, n)) {
 		if (ND_ptr(n)) {
@@ -515,7 +444,7 @@ static Agraph_t *deriveGraph(Agraph_t * g)
 	if (ND_dn(n))
 	    continue;
 	dn = agnode(dg, agnameof(n), 1);
-	agbindrec (dn, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
+	agbindrec (dn, "nodeinfo", sizeof(Agnodeinfo_t), true);
 	ND_ptr(dn) = (Agobj_t*)n;
 	ND_ptr(n) = (Agobj_t*)dn;
     }
@@ -562,7 +491,7 @@ typedef int (*qsort_cmpf) (const void *, const void *);
 
 static int cmp(Agraph_t** p0, Agraph_t** p1)
 {
-    return (agnnodes(*p1) - agnnodes(*p0));
+    return agnnodes(*p1) - agnnodes(*p0);
 }
 
 static void
@@ -631,7 +560,6 @@ static int processClusters(Agraph_t * g, char* graphName)
 {
     Agraph_t *dg;
     long n_cnt, c_cnt, e_cnt;
-    char *name;
     Agraph_t *out;
     Agnode_t *n;
     Agraph_t *dout;
@@ -647,10 +575,13 @@ static int processClusters(Agraph_t * g, char* graphName)
 		    x_node, agnameof(g));
 	    return 1;
 	}
-	name = getBuf(sizeof(PFX1) + strlen(graphName));
-	sprintf(name, PFX1, graphName);
-	dout = agsubg(dg, name, 1);
-	out = agsubg(g, name, 1);
+	{
+	    char *name = gv_alloc(sizeof(PFX1) + strlen(graphName));
+	    sprintf(name, PFX1, graphName);
+	    dout = agsubg(dg, name, 1);
+	    out = agsubg(g, name, 1);
+	    free(name);
+	}
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
 	dn = ND_dn(n);
@@ -672,10 +603,13 @@ static int processClusters(Agraph_t * g, char* graphName)
     for (dn = agfstnode(dg); dn; dn = agnxtnode(dg, dn)) {
 	if (ND_mark(dn))
 	    continue;
-	name = getBuf(sizeof(PFX2) + strlen(graphName) + 32);
-	sprintf(name, PFX2, graphName, c_cnt);
-	dout = agsubg(dg, name, 1);
-	out = agsubg(g, name, 1);
+	{
+	    char *name = gv_alloc(sizeof(PFX2) + strlen(graphName) + 32);
+	    sprintf(name, PFX2, graphName, c_cnt);
+	    dout = agsubg(dg, name, 1);
+	    out = agsubg(g, name, 1);
+	    free(name);
+	}
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
 	n_cnt = dfs(dg, dn, dout);
@@ -701,7 +635,7 @@ static int processClusters(Agraph_t * g, char* graphName)
 	    }
 	    else if (x_mode == BY_SIZE) {
 		int sz = agnnodes(out);
-		if ((x_index <= sz) && ((x_final == -1) || (sz <= x_final))) {
+		if (x_index <= sz && (x_final == -1 || sz <= x_final)) {
 		    extracted = 1;
 		    if (doAll)
 			subGInduce(g, out);
@@ -717,7 +651,7 @@ static int processClusters(Agraph_t * g, char* graphName)
 		    c_cnt, n_cnt, e_cnt);
 	c_cnt++;
     }
-    if ((printMode == EXTRACT) && !extracted && (x_mode == BY_INDEX))  {
+    if (printMode == EXTRACT && !extracted && x_mode == BY_INDEX)  {
 	fprintf(stderr,
 		"ccomps: component %d not found in graph %s - ignored\n",
 		x_index, agnameof(g));
@@ -755,14 +689,12 @@ bindGraphinfo (Agraph_t * g)
 static int process(Agraph_t * g, char* graphName)
 {
     long n_cnt, c_cnt, e_cnt;
-    char *name;
     Agraph_t *out;
     Agnode_t *n;
     int extracted = 0;
 
     aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), TRUE);
     bindGraphinfo (g);
-    initStk();
 
     if (useClusters)
 	return processClusters(g, graphName);
@@ -775,9 +707,12 @@ static int process(Agraph_t * g, char* graphName)
 		    x_node, agnameof(g));
 	    return 1;
 	}
-	name = getBuf(sizeof(PFX1) + strlen(graphName));
-	sprintf(name, PFX1, graphName);
-	out = agsubg(g, name, 1);
+	{
+	    char *name = gv_alloc(sizeof(PFX1) + strlen(graphName));
+	    sprintf(name, PFX1, graphName);
+	    out = agsubg(g, name, 1);
+	    free(name);
+	}
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
 	n_cnt = dfs(g, n, out);
@@ -797,9 +732,12 @@ static int process(Agraph_t * g, char* graphName)
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (ND_mark(n))
 	    continue;
-	name = getBuf(sizeof(PFX2) + strlen(graphName) + 32);
-	sprintf(name, PFX2, graphName, c_cnt);
-	out = agsubg(g, name, 1);
+	{
+	    char *name = gv_alloc(sizeof(PFX2) + strlen(graphName) + 32);
+	    sprintf(name, PFX2, graphName, c_cnt);
+	    out = agsubg(g, name, 1);
+	    free(name);
+	}
 	aginit(out, AGRAPH, "graphinfo", sizeof(Agraphinfo_t), TRUE);
 	GD_cc_subg(out) = 1;
 	n_cnt = dfs(g, n, out);
@@ -824,7 +762,7 @@ static int process(Agraph_t * g, char* graphName)
 	    }
 	    else if (x_mode == BY_SIZE) {
 		int sz = agnnodes(out);
-		if ((x_index <= sz) && ((x_final == -1) || (sz <= x_final))) {
+		if (x_index <= sz && (x_final == -1 || sz <= x_final)) {
 		    extracted = 1;
 		    if (doAll)
 			subGInduce(g, out);
@@ -839,7 +777,7 @@ static int process(Agraph_t * g, char* graphName)
 		    c_cnt, n_cnt, e_cnt);
 	c_cnt++;
     }
-    if ((printMode == EXTRACT) && !extracted && (x_mode == BY_INDEX))  {
+    if (printMode == EXTRACT && !extracted && x_mode == BY_INDEX)  {
 	fprintf(stderr,
 		"ccomps: component %d not found in graph %s - ignored\n",
 		x_index, agnameof(g));
@@ -854,12 +792,12 @@ static int process(Agraph_t * g, char* graphName)
     if (verbose)
 	fprintf(stderr, "       %7d nodes %7d edges %7ld components %s\n",
 		agnnodes(g), agnedges(g), c_cnt, agnameof(g));
-    return (c_cnt > 1);
+    return c_cnt > 1;
 }
 
 static Agraph_t *gread(FILE * fp)
 {
-    return agread(fp, (Agdisc_t *) 0);
+    return agread(fp, NULL);
 }
 
 /* chkGraphName:
@@ -877,14 +815,13 @@ static char*
 chkGraphName (Agraph_t* g)
 {
     static char* buf = NULL;
-    static int buflen = 0;
+    static size_t buflen = 0;
     char* s = agnameof(g);
-    int len;
 
     if (*s != '%') return s;
-    len = strlen(s) + 2;   /* plus '\0' and '_' */
+    size_t len = strlen(s) + 2;   /* plus '\0' and '_' */
     if (len > buflen) {
-	buf = realloc (buf, len);
+	buf = gv_realloc(buf, buflen, len);
 	buflen = len;
     }
     buf[0] = '_';
@@ -906,5 +843,7 @@ int main(int argc, char *argv[])
 	agclose(g);
     }
 
-    return r;
+    stack_reset(&Stk);
+
+    graphviz_exit(r);
 }
