@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief <a href=https://en.wikipedia.org/wiki/GraphML>GRAPHML</a>-DOT converter
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -11,7 +16,13 @@
 
 #include    "convert.h"
 #include    <cgraph/agxbuf.h>
+#include    <cgraph/alloc.h>
+#include    <cgraph/exit.h>
+#include    <cgraph/likely.h>
+#include    <cgraph/stack.h>
 #include    <getopt.h>
+#include    <stdio.h>
+#include    <string.h>
 #ifdef HAVE_EXPAT
 #include    <expat.h>
 #include    <ctype.h>
@@ -20,8 +31,6 @@
 #define XML_STATUS_ERROR 0
 #endif
 
-#define STACK_DEPTH	32
-#define BUFSIZE		20000
 #define SMALLBUF	1000
 #define NAMEBUF		100
 
@@ -46,63 +55,50 @@ static char **Files;
 static int Verbose;
 static char* gname = "";
 
-typedef struct slist slist;
-struct slist {
-    slist *next;
-    char buf[1];
-};
+static void pushString(gv_stack_t *stk, const char *s) {
 
-#define NEW(t)      malloc(sizeof(t))
-#define N_NEW(n,t)  calloc((n),sizeof(t))
-/* Round x up to next multiple of y, which is a power of 2 */
-#define ROUND2(x,y) (((x) + ((y)-1)) & ~((y)-1))
+  // duplicate the string we will push
+  char *copy = gv_strdup(s);
 
-static void pushString(slist ** stk, const char *s)
-{
-    int sz = ROUND2(sizeof(slist) + strlen(s), sizeof(void *));
-    slist *sp = N_NEW(sz, char);
-    strcpy(sp->buf, s);
-    sp->next = *stk;
-    *stk = sp;
+  // push this onto the stack
+  stack_push_or_exit(stk, copy);
 }
 
-static void popString(slist ** stk)
-{
-    slist *sp = *stk;
-    if (!sp) {
-	fprintf(stderr, "PANIC: graphml2gv: empty element stack\n");
-	exit(1);
-    }
-    *stk = sp->next;
-    free(sp);
+static void popString(gv_stack_t *stk) {
+
+  if (UNLIKELY(stack_is_empty(stk))) {
+    fprintf(stderr, "PANIC: graphml2gv: empty element stack\n");
+    graphviz_exit(EXIT_FAILURE);
+  }
+
+  char *s = stack_pop(stk);
+  free(s);
 }
 
-static char *topString(slist * stk)
-{
-    if (!stk) {
-	fprintf(stderr, "PANIC: graphml2gv: empty element stack\n");
-	exit(1);
-    }
-    return stk->buf;
+static char *topString(gv_stack_t *stk) {
+
+  if (UNLIKELY(stack_is_empty(stk))) {
+    fprintf(stderr, "PANIC: graphml2gv: empty element stack\n");
+    graphviz_exit(EXIT_FAILURE);
+  }
+
+  return stack_top(stk);
 }
 
-static void freeString(slist * stk)
-{
-    slist *sp;
-
-    while (stk) {
-	sp = stk->next;
-	free(stk);
-	stk = sp;
-    }
+static void freeString(gv_stack_t *stk) {
+  while (!stack_is_empty(stk)) {
+    char *s = stack_pop(stk);
+    free(s);
+  }
+  stack_reset(stk);
 }
 
-typedef struct userdata {
+typedef struct {
     agxbuf xml_attr_name;
     agxbuf xml_attr_value;
     agxbuf composite_buffer;
     char* gname;
-    slist *elements;
+    gv_stack_t elements;
     int listen;
     int closedElementType;
     int globalAttrType;
@@ -117,8 +113,7 @@ static Agraph_t *G;		/* Current graph */
 static Agnode_t *N;		/* Set if Current_class == TAG_NODE */
 static Agedge_t *E;		/* Set if Current_class == TAG_EDGE */
 
-static int GSP;
-static Agraph_t *Gstack[STACK_DEPTH];
+static gv_stack_t Gstack;
 
 typedef struct {
     Dtlink_t link;
@@ -128,7 +123,7 @@ typedef struct {
 
 static namev_t *make_nitem(Dt_t * d, namev_t * objp, Dtdisc_t * disc)
 {
-    namev_t *np = NEW(namev_t);
+    namev_t *np = gv_alloc(sizeof(*np));
     np->name = objp->name;
     np->unique_name = 0;
     return np;
@@ -141,25 +136,21 @@ static void free_nitem(Dt_t * d, namev_t * np, Dtdisc_t * disc)
 }
 
 static Dtdisc_t nameDisc = {
-    offsetof(namev_t, name),
-    -1,
-    offsetof(namev_t, link),
-    (Dtmake_f) make_nitem,
-    (Dtfree_f) free_nitem,
-    NIL(Dtcompar_f),
-    NIL(Dthash_f),
-    NIL(Dtmemory_f),
-    NIL(Dtevent_f)
+    .key = offsetof(namev_t, name),
+    .size = -1,
+    .link = offsetof(namev_t, link),
+    .makef = (Dtmake_f)make_nitem,
+    .freef = (Dtfree_f)free_nitem,
 };
 
 static userdata_t *genUserdata(char* dfltname)
 {
-    userdata_t *user = NEW(userdata_t);
+    userdata_t *user = gv_alloc(sizeof(*user));
     agxbinit(&(user->xml_attr_name), NAMEBUF, 0);
     agxbinit(&(user->xml_attr_value), SMALLBUF, 0);
     agxbinit(&(user->composite_buffer), SMALLBUF, 0);
     user->listen = FALSE;
-    user->elements = 0;
+    user->elements = (gv_stack_t){0};
     user->closedElementType = TAG_NONE;
     user->globalAttrType = TAG_NONE;
     user->compositeReadState = FALSE;
@@ -175,7 +166,7 @@ static void freeUserdata(userdata_t * ud)
     agxbfree(&(ud->xml_attr_name));
     agxbfree(&(ud->xml_attr_value));
     agxbfree(&(ud->composite_buffer));
-    freeString(ud->elements);
+    freeString(&ud->elements);
     free(ud);
 }
 
@@ -190,8 +181,7 @@ static void addToMap(Dt_t * map, char *name, char *uniqueName)
     objp->unique_name = strdup(uniqueName);
 }
 
-static char *mapLookup(Dt_t * nm, char *name)
-{
+static char *mapLookup(Dt_t *nm, const char *name) {
     namev_t *objp = dtmatch(nm, name);
     if (objp)
 	return objp->unique_name;
@@ -199,37 +189,44 @@ static char *mapLookup(Dt_t * nm, char *name)
 	return 0;
 }
 
-static int isAnonGraph(char *name)
-{
+static int isAnonGraph(const char *name) {
     if (*name++ != '%')
 	return 0;
-    while (isdigit(*name))
+    while (isdigit((int)*name))
 	name++;			/* skip over digits */
     return (*name == '\0');
 }
 
 static void push_subg(Agraph_t * g)
 {
-    if (GSP == STACK_DEPTH) {
-	fprintf(stderr, "graphml2gv: Too many (> %d) nestings of subgraphs\n",
-		STACK_DEPTH);
-	exit(1);
-    } else if (GSP == 0)
-	root = g;
-    G = Gstack[GSP++] = g;
+  // save the root if this is the first graph
+  if (stack_is_empty(&Gstack)) {
+    root = g;
+  }
+
+  // insert the new graph
+  stack_push_or_exit(&Gstack, g);
+
+  // update the top graph
+  G = g;
 }
 
 static Agraph_t *pop_subg(void)
 {
-    Agraph_t *g;
-    if (GSP == 0) {
-	fprintf(stderr, "graphml2gv: Gstack underflow in graph parser\n");
-	exit(1);
-    }
-    g = Gstack[--GSP];
-    if (GSP > 0)
-	G = Gstack[GSP - 1];
-    return g;
+  if (stack_is_empty(&Gstack)) {
+    fprintf(stderr, "graphml2gv: Gstack underflow in graph parser\n");
+    graphviz_exit(EXIT_FAILURE);
+  }
+
+  // pop the top graph
+  Agraph_t *g = stack_pop(&Gstack);
+
+  // update the top graph
+  if (!stack_is_empty(&Gstack)) {
+    G = stack_top(&Gstack);
+  }
+
+  return g;
 }
 
 static Agnode_t *bind_node(const char *name)
@@ -300,7 +297,7 @@ setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud)
  * The names must always begin with "node:".
  */
 static void
-setGlobalNodeAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
+setGlobalNodeAttr(Agraph_t * g, char *name, char *value)
 {
     if (strncmp(name, NODELBL, NLBLLEN))
 	fprintf(stderr,
@@ -350,7 +347,7 @@ setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
  * The names always begin with "edge:".
  */
 static void
-setGlobalEdgeAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
+setGlobalEdgeAttr(Agraph_t * g, char *name, char *value)
 {
     if (strncmp(name, EDGELBL, ELBLLEN))
 	fprintf(stderr,
@@ -406,7 +403,7 @@ static void
 startElementHandler(void *userData, const char *name, const char **atts)
 {
     int pos;
-    userdata_t *ud = (userdata_t *) userData;
+    userdata_t *ud = userData;
     Agraph_t *g = NULL;
 
     if (strcmp(name, "graphml") == 0) {
@@ -433,7 +430,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    edgeMode = atts[pos];
 	}
 
-	if (GSP == 0) {
+	if (stack_is_empty(&Gstack)) {
 	    if (strcmp(edgeMode, "directed") == 0) {
 		dir = Agdirected;
 	    } else if (strcmp(edgeMode, "undirected") == 0) {
@@ -449,7 +446,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    push_subg(g);
 	} else {
 	    Agraph_t *subg;
-	    if (isAnonGraph((char *) id)) {
+	    if (isAnonGraph(id)) {
 		static int anon_id = 1;
 		snprintf(buf, sizeof(buf), "%%%d", anon_id++);
 		id = buf;
@@ -486,11 +483,11 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	if (pos > 0)
 	    head = atts[pos];
 
-	tname = mapLookup(ud->nameMap, (char *) tail);
+	tname = mapLookup(ud->nameMap, tail);
 	if (tname)
 	    tail = tname;
 
-	tname = mapLookup(ud->nameMap, (char *) head);
+	tname = mapLookup(ud->nameMap, head);
 	if (tname)
 	    head = tname;
 
@@ -523,14 +520,14 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 static void endElementHandler(void *userData, const char *name)
 {
-    userdata_t *ud = (userdata_t *) userData;
+    userdata_t *ud = userData;
 
     if (strcmp(name, "graph") == 0) {
 	pop_subg();
 	popString(&ud->elements);
 	ud->closedElementType = TAG_GRAPH;
     } else if (strcmp(name, "node") == 0) {
-	char *ele_name = topString(ud->elements);
+	char *ele_name = topString(&ud->elements);
 	if (ud->closedElementType == TAG_GRAPH) {
 	    Agnode_t *node = agnode(root, ele_name, 0);
 	    if (node) agdelete(root, node);
@@ -547,20 +544,13 @@ static void endElementHandler(void *userData, const char *name)
     } else if (strcmp(name, "attr") == 0) {
 	char *name;
 	char *value;
-	char buf[SMALLBUF] = GRAPHML_COMP;
 	char *dynbuf = 0;
 
 	ud->closedElementType = TAG_NONE;
 	if (ud->compositeReadState) {
-	    int len = sizeof(GRAPHML_COMP) + agxblen(&ud->xml_attr_name);
-	    if (len <= SMALLBUF) {
-		name = buf;
-	    } else {
-		name = dynbuf = N_NEW(len, char);
-		strcpy(name, GRAPHML_COMP);
-	    }
-	    strcpy(name + sizeof(GRAPHML_COMP) - 1,
-		   agxbuse(&ud->xml_attr_name));
+	    size_t len = sizeof(GRAPHML_COMP) + agxblen(&ud->xml_attr_name);
+	    name = dynbuf = gv_calloc(len, sizeof(char));
+	    (void)snprintf(name, len, "%s%s", GRAPHML_COMP, agxbuse(&ud->xml_attr_name));
 	    value = agxbuse(&ud->composite_buffer);
 	    agxbclear(&ud->xml_attr_value);
 	    ud->compositeReadState = FALSE;
@@ -574,10 +564,10 @@ static void endElementHandler(void *userData, const char *name)
 	    setAttr(name, value, ud);
 	    break;
 	case TAG_NODE:
-	    setGlobalNodeAttr(G, name, value, ud);
+	    setGlobalNodeAttr(G, name, value);
 	    break;
 	case TAG_EDGE:
-	    setGlobalEdgeAttr(G, name, value, ud);
+	    setGlobalEdgeAttr(G, name, value);
 	    break;
 	case TAG_GRAPH:
 	    setGraphAttr(G, name, value, ud);
@@ -590,22 +580,22 @@ static void endElementHandler(void *userData, const char *name)
 
 static void characterDataHandler(void *userData, const char *s, int length)
 {
-    userdata_t *ud = (userdata_t *) userData;
+    userdata_t *ud = userData;
 
     if (!ud->listen)
 	return;
 
     if (ud->compositeReadState) {
-	agxbput_n(&ud->composite_buffer, (char *) s, length);
+	agxbput_n(&ud->composite_buffer, s, length);
 	return;
     }
 
-    agxbput_n(&ud->xml_attr_value, (char *) s, length);
+    agxbput_n(&ud->xml_attr_value, s, length);
 }
 
 static Agraph_t *graphml_to_gv(char* gname, FILE * graphmlFile, int* rv)
 {
-    char buf[BUFSIZE];
+    char buf[BUFSIZ];
     int done;
     userdata_t *udata = genUserdata(gname);
     XML_Parser parser = XML_ParserCreate(NULL);
@@ -669,7 +659,7 @@ static FILE *openFile(const char *name)
     if (!fp) {
 	fprintf(stderr, "%s: could not open file %s for writing\n", CmdName, name);
 	perror(name);
-	exit(1);
+	graphviz_exit(1);
     }
     return fp;
 }
@@ -683,7 +673,7 @@ static const char *use = "Usage: %s [-gd?] [-o<file>] [<graphs>]\n\
 static void usage(int v)
 {
     fprintf(stderr, use, CmdName);
-    exit(v);
+    graphviz_exit(v);
 }
 
 static char *cmdName(char *path)
@@ -750,7 +740,7 @@ nameOf (char* name, int cnt)
 	return name;
     if (cnt) {
 	if (!buf)
-	    buf = N_NEW (strlen(name)+32,char);  /* 32 to handle any integer plus null byte */
+	    buf = gv_calloc(strlen(name) + 32, sizeof(char)); // 32 to handle any integer plus null byte
 	sprintf (buf, "%s%d", name, cnt);
 	return buf;
     }
@@ -782,9 +772,12 @@ int main(int argc, char **argv)
 	    fflush(outFile);
 	}
     }
-    exit(rv);
+
+    stack_reset(&Gstack);
+
+    graphviz_exit(rv);
 #else
     fputs("cvtgxl: not configured for conversion from GXL to GV\n", stderr);
-    exit(1);
+    graphviz_exit(1);
 #endif
 }
