@@ -1,3 +1,8 @@
+/**
+ * @file
+ * @brief <a href=https://en.wikipedia.org/wiki/GXL>GXL</a>-DOT convert subroutines
+ */
+
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,19 +13,26 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
+#include    <assert.h>
 #include    "convert.h"
 #include    <cgraph/agxbuf.h>
+#include    <cgraph/alloc.h>
+#include    <cgraph/exit.h>
+#include    <cgraph/likely.h>
+#include    <cgraph/stack.h>
+#include    <common/memory.h>
+#include    <stdio.h>
 #ifdef HAVE_EXPAT
 #include    <expat.h>
 #include    <ctype.h>
+#include    <limits.h>
+#include    <stdbool.h>
+#include    <stdlib.h>
 
 #ifndef XML_STATUS_ERROR
 #define XML_STATUS_ERROR 0
 #endif
 
-#define STACK_DEPTH	32
-#define BUFSIZE		20000
 #define SMALLBUF	1000
 #define NAMEBUF		100
 
@@ -34,91 +46,72 @@
 #define GXL_COMP    "_gxl_composite_"
 #define GXL_LOC     "_gxl_locator_"
 
-#define	TAG_NONE	-1
-#define	TAG_GRAPH	0
-#define TAG_NODE	1
-#define TAG_EDGE	2
+typedef enum {
+  TAG_NONE,
+  TAG_GRAPH,
+  TAG_NODE,
+  TAG_EDGE,
+  TAG_HTML_LIKE_STRING,
+} attr_t;
 
-typedef struct slist slist;
-struct slist {
-    slist *next;
-    char buf[1];
-};
+static void pushString(gv_stack_t *stk, const char *s) {
 
-static void *gcalloc(size_t nmemb, size_t size)
-{
-    char *rv = calloc(nmemb, size);
-    if (rv == NULL) {
-	fprintf(stderr, "out of memory\n");
-	exit(EXIT_FAILURE);
-    }
-    return rv;
+  // duplicate the string we will push
+  char *copy = gv_strdup(s);
+
+  // push this onto the stack
+  stack_push_or_exit(stk, copy);
 }
 
-/* Round x up to next multiple of y, which is a power of 2 */
-#define ROUND2(x,y) (((x) + ((y)-1)) & ~((y)-1))
+static void popString(gv_stack_t *stk) {
 
-static void pushString(slist ** stk, const char *s)
-{
-    int sz = ROUND2(sizeof(slist) + strlen(s), sizeof(void *));
-    slist *sp = gcalloc(sz, sizeof(char));
-    strcpy(sp->buf, s);
-    sp->next = *stk;
-    *stk = sp;
+  if (UNLIKELY(stack_is_empty(stk))) {
+    fprintf(stderr, "PANIC: gxl2gv: empty element stack\n");
+    graphviz_exit(EXIT_FAILURE);
+  }
+
+  char *s = stack_pop(stk);
+  free(s);
 }
 
-static void popString(slist ** stk)
-{
-    slist *sp = *stk;
-    if (!sp) {
-	fprintf(stderr, "PANIC: gxl2gv: empty element stack\n");
-	exit(1);
-    }
-    *stk = sp->next;
-    free(sp);
+static char *topString(gv_stack_t *stk) {
+
+  if (UNLIKELY(stack_is_empty(stk))) {
+    fprintf(stderr, "PANIC: gxl2gv: empty element stack\n");
+    graphviz_exit(EXIT_FAILURE);
+  }
+
+  return stack_top(stk);
 }
 
-static char *topString(slist * stk)
-{
-    if (!stk) {
-	fprintf(stderr, "PANIC: gxl2gv: empty element stack\n");
-	exit(1);
-    }
-    return stk->buf;
+static void freeString(gv_stack_t *stk) {
+  while (!stack_is_empty(stk)) {
+    char *s = stack_pop(stk);
+    free(s);
+  }
+  stack_reset(stk);
 }
 
-static void freeString(slist * stk)
-{
-    slist *sp;
-
-    while (stk) {
-	sp = stk->next;
-	free(stk);
-	stk = sp;
-    }
-}
-
-typedef struct userdata {
+typedef struct {
     agxbuf xml_attr_name;
     agxbuf xml_attr_value;
     agxbuf composite_buffer;
-    slist *elements;
+    gv_stack_t elements;
     int listen;
-    int closedElementType;
-    int globalAttrType;
+    attr_t closedElementType;
+    attr_t globalAttrType;
     int compositeReadState;
     int edgeinverted;
     Dt_t *nameMap;
 } userdata_t;
 
 static Agraph_t *root;		/* root graph */
-static int Current_class;	/* Current element type */
+static attr_t Current_class;	/* Current element type */
 static Agraph_t *G;		/* Current graph */
 static Agnode_t *N;		/* Set if Current_class == TAG_NODE */
 static Agedge_t *E;		/* Set if Current_class == TAG_EDGE */
 
-static int GSP;
-static Agraph_t *Gstack[STACK_DEPTH];
+static gv_stack_t Gstack;
 
 typedef struct {
     Dtlink_t link;
@@ -128,6 +121,9 @@ typedef struct {
 
 static namev_t *make_nitem(Dt_t * d, namev_t * objp, Dtdisc_t * disc)
 {
+    (void)d;
+    (void)disc;
+
     namev_t *np = malloc(sizeof(namev_t));
     if (np == NULL)
 	return NULL;
@@ -138,20 +134,19 @@ static namev_t *make_nitem(Dt_t * d, namev_t * objp, Dtdisc_t * disc)
 
 static void free_nitem(Dt_t * d, namev_t * np, Dtdisc_t * disc)
 {
+    (void)d;
+    (void)disc;
+
     free(np->unique_name);
     free(np);
 }
 
 static Dtdisc_t nameDisc = {
-    offsetof(namev_t, name),
-    -1,
-    offsetof(namev_t, link),
-    (Dtmake_f) make_nitem,
-    (Dtfree_f) free_nitem,
-    NIL(Dtcompar_f),
-    NIL(Dthash_f),
-    NIL(Dtmemory_f),
-    NIL(Dtevent_f)
+    .key = offsetof(namev_t, name),
+    .size = -1,
+    .link = offsetof(namev_t, link),
+    .makef = (Dtmake_f)make_nitem,
+    .freef = (Dtfree_f)free_nitem,
 };
 
 static userdata_t *genUserdata(void)
@@ -163,7 +158,7 @@ static userdata_t *genUserdata(void)
     agxbinit(&(user->xml_attr_value), SMALLBUF, 0);
     agxbinit(&(user->composite_buffer), SMALLBUF, 0);
     user->listen = FALSE;
-    user->elements = 0;
+    user->elements = (gv_stack_t){0};
     user->closedElementType = TAG_NONE;
     user->globalAttrType = TAG_NONE;
     user->compositeReadState = FALSE;
@@ -178,7 +173,7 @@ static void freeUserdata(userdata_t * ud)
     agxbfree(&(ud->xml_attr_name));
     agxbfree(&(ud->xml_attr_value));
     agxbfree(&(ud->composite_buffer));
-    freeString(ud->elements);
+    freeString(&ud->elements);
     free(ud);
 }
 
@@ -193,8 +188,7 @@ static void addToMap(Dt_t * map, char *name, char *uniqueName)
     objp->unique_name = strdup(uniqueName);
 }
 
-static char *mapLookup(Dt_t * nm, char *name)
-{
+static char *mapLookup(Dt_t *nm, const char *name) {
     namev_t *objp = dtmatch(nm, name);
     if (objp)
 	return objp->unique_name;
@@ -202,37 +196,45 @@ static char *mapLookup(Dt_t * nm, char *name)
 	return 0;
 }
 
-static int isAnonGraph(char *name)
+static int isAnonGraph(const char *name)
 {
     if (*name++ != '%')
 	return 0;
-    while (isdigit(*name))
+    while (isdigit((int)*name))
 	name++;			/* skip over digits */
     return (*name == '\0');
 }
 
 static void push_subg(Agraph_t * g)
 {
-    if (GSP == STACK_DEPTH) {
-	fprintf(stderr, "gxl2gv: Too many (> %d) nestings of subgraphs\n",
-		STACK_DEPTH);
-	exit(1);
-    } else if (GSP == 0)
-	root = g;
-    G = Gstack[GSP++] = g;
+  // insert the new graph
+  stack_push_or_exit(&Gstack, g);
+
+  // save the root if this is the first graph
+  if (stack_size(&Gstack) == 1) {
+    root = g;
+  }
+
+  // update the top graph
+  G = g;
 }
 
 static Agraph_t *pop_subg(void)
 {
-    Agraph_t *g;
-    if (GSP == 0) {
-	fprintf(stderr, "gxl2gv: Gstack underflow in graph parser\n");
-	exit(1);
-    }
-    g = Gstack[--GSP];
-    if (GSP > 0)
-	G = Gstack[GSP - 1];
-    return g;
+  // is the stack empty?
+  if (stack_is_empty(&Gstack)) {
+    fprintf(stderr, "gxl2gv: Gstack underflow in graph parser\n");
+    graphviz_exit(EXIT_FAILURE);
+  }
+
+  // pop the top graph
+  Agraph_t *g = stack_pop(&Gstack);
+
+  // update the top graph
+  if (!stack_is_empty(&Gstack))
+    G = stack_top(&Gstack);
+
+  return g;
 }
 
 static Agnode_t *bind_node(const char *name)
@@ -279,7 +281,8 @@ static void setName(Dt_t * names, Agobj_t * n, char *value)
 static char *defval = "";
 
 static void
-setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud)
+setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud,
+  bool is_html)
 {
     Agsym_t *ap;
 
@@ -289,7 +292,13 @@ setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud)
 	ap = agattr(root, AGNODE, name, 0);
 	if (!ap)
 	    ap = agattr(root, AGNODE, name, defval);
-	agxset(np, ap, value);
+	if (is_html) {
+	    char *val = agstrdup_html(root, value);
+	    agxset(np, ap, val);
+	    agstrfree(root, val); // drop the extra reference count we bumped for val
+	} else {
+	    agxset(np, ap, value);
+	}
     }
 }
 
@@ -303,7 +312,7 @@ setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud)
  * The names must always begin with "node:".
  */
 static void
-setGlobalNodeAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
+setGlobalNodeAttr(Agraph_t * g, char *name, char *value)
 {
     if (strncmp(name, NODELBL, NLBLLEN))
 	fprintf(stderr,
@@ -317,7 +326,8 @@ setGlobalNodeAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
 }
 
 static void
-setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
+setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud,
+  bool is_html)
 {
     Agsym_t *ap;
     char *attrname;
@@ -330,7 +340,6 @@ setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
 	ap = agattr(root, AGEDGE, attrname, 0);
 	if (!ap)
 	    ap = agattr(root, AGEDGE, attrname, defval);
-	agxset(ep, ap, value);
     } else if (strcmp(name, "tailport") == 0) {
 	if (ud->edgeinverted)
 	    attrname = "headport";
@@ -339,11 +348,17 @@ setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
 	ap = agattr(root, AGEDGE, attrname, 0);
 	if (!ap)
 	    ap = agattr(root, AGEDGE, attrname, defval);
-	agxset(ep, ap, value);
     } else {
 	ap = agattr(root, AGEDGE, name, 0);
 	if (!ap)
 	    ap = agattr(root, AGEDGE, name, defval);
+    }
+
+    if (is_html) {
+	char *val = agstrdup_html(root, value);
+	agxset(ep, ap, val);
+	agstrfree(root, val); // drop the extra reference count we bumped for val
+    } else {
 	agxset(ep, ap, value);
     }
 }
@@ -353,7 +368,7 @@ setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
  * The names always begin with "edge:".
  */
 static void
-setGlobalEdgeAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
+setGlobalEdgeAttr(Agraph_t * g, char *name, char *value)
 {
     if (strncmp(name, EDGELBL, ELBLLEN))
 	fprintf(stderr,
@@ -388,17 +403,19 @@ setGraphAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
     }
 }
 
-static void setAttr(char *name, char *value, userdata_t * ud)
+static void setAttr(char *name, char *value, userdata_t * ud, bool is_html)
 {
     switch (Current_class) {
     case TAG_GRAPH:
 	setGraphAttr(G, name, value, ud);
 	break;
     case TAG_NODE:
-	setNodeAttr(N, name, value, ud);
+	setNodeAttr(N, name, value, ud, is_html);
 	break;
     case TAG_EDGE:
-	setEdgeAttr(E, name, value, ud);
+	setEdgeAttr(E, name, value, ud, is_html);
+	break;
+    default:
 	break;
     }
 }
@@ -409,7 +426,7 @@ static void
 startElementHandler(void *userData, const char *name, const char **atts)
 {
     int pos;
-    userdata_t *ud = (userdata_t *) userData;
+    userdata_t *ud = userData;
     Agraph_t *g = NULL;
 
     if (strcmp(name, "gxl") == 0) {
@@ -430,7 +447,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    edgeMode = atts[pos];
 	}
 
-	if (GSP == 0) {
+	if (stack_is_empty(&Gstack)) {
 	    if (strcmp(edgeMode, "directed") == 0) {
 		g = agopen((char *) id, Agdirected, &AgDefaultDisc);
 	    } else if (strcmp(edgeMode, "undirected") == 0) {
@@ -444,7 +461,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    push_subg(g);
 	} else {
 	    Agraph_t *subg;
-	    if (isAnonGraph((char *) id)) {
+	    if (isAnonGraph(id)) {
 		static int anon_id = 1;
 		snprintf(buf, sizeof(buf), "%%%d", anon_id++);
 		id = buf;
@@ -471,9 +488,11 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    const char *attrname;
 	    attrname = atts[pos];
 
-	    bind_node(attrname);
+	    if (attrname != NULL && strcmp(attrname, "") != 0) {
+		bind_node(attrname);
 
-	    pushString(&ud->elements, attrname);
+		pushString(&ud->elements, attrname);
+	    }
 	}
 
     } else if (strcmp(name, "edge") == 0) {
@@ -489,11 +508,11 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	if (pos > 0)
 	    head = atts[pos];
 
-	tname = mapLookup(ud->nameMap, (char *) tail);
+	tname = mapLookup(ud->nameMap, tail);
 	if (tname)
 	    tail = tname;
 
-	tname = mapLookup(ud->nameMap, (char *) head);
+	tname = mapLookup(ud->nameMap, head);
 	if (tname)
 	    head = tname;
 
@@ -510,22 +529,22 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 	pos = get_xml_attr("fromorder", atts);
 	if (pos > 0) {
-	    setEdgeAttr(E, GXL_FROM, (char *) atts[pos], ud);
+	    setEdgeAttr(E, GXL_FROM, (char *) atts[pos], ud, false);
 	}
 
 	pos = get_xml_attr("toorder", atts);
 	if (pos > 0) {
-	    setEdgeAttr(E, GXL_TO, (char *) atts[pos], ud);
+	    setEdgeAttr(E, GXL_TO, (char *) atts[pos], ud, false);
 	}
 
 	pos = get_xml_attr("id", atts);
 	if (pos > 0) {
-	    setEdgeAttr(E, GXL_ID, (char *) atts[pos], ud);
+	    setEdgeAttr(E, GXL_ID, (char *) atts[pos], ud, false);
 	}
     } else if (strcmp(name, "attr") == 0) {
 	const char *attrname = atts[get_xml_attr("name", atts)];
 
-	agxbput(&ud->xml_attr_name, (char *) attrname);
+	agxbput(&ud->xml_attr_name, attrname);
 	pos = get_xml_attr("kind", atts);
 
 	if (pos > 0) {
@@ -535,6 +554,8 @@ startElementHandler(void *userData, const char *name, const char **atts)
 		ud->globalAttrType = TAG_EDGE;
 	    else if (strcmp("graph", atts[pos]) == 0)
 		ud->globalAttrType = TAG_GRAPH;
+	    else if (strcmp("HTML-like string", atts[pos]) == 0)
+		ud->globalAttrType = TAG_HTML_LIKE_STRING;
 	} else {
 	    ud->globalAttrType = TAG_NONE;
 	}
@@ -552,7 +573,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
     } else if (strcmp(name, "type") == 0) {
 	pos = get_xml_attr("xlink:href", atts);
 	if (pos > 0) {
-	    setAttr(GXL_TYPE, (char *) atts[pos], ud);
+	    setAttr(GXL_TYPE, (char *) atts[pos], ud, false);
 	}
     } else if (strcmp(name, "locator") == 0) {
 	pos = get_xml_attr("xlink:href", atts);
@@ -577,14 +598,14 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 static void endElementHandler(void *userData, const char *name)
 {
-    userdata_t *ud = (userdata_t *) userData;
+    userdata_t *ud = userData;
 
     if (strcmp(name, "graph") == 0) {
 	pop_subg();
 	popString(&ud->elements);
 	ud->closedElementType = TAG_GRAPH;
     } else if (strcmp(name, "node") == 0) {
-	char *ele_name = topString(ud->elements);
+	char *ele_name = topString(&ud->elements);
 	if (ud->closedElementType == TAG_GRAPH) {
 	    Agnode_t *node = agnode(root, ele_name, 0);
 	    agdelete(root, node);
@@ -599,42 +620,45 @@ static void endElementHandler(void *userData, const char *name)
 	ud->closedElementType = TAG_EDGE;
 	ud->edgeinverted = FALSE;
     } else if (strcmp(name, "attr") == 0) {
-	char *name;
+	char *new_name;
 	char *value;
 	char buf[SMALLBUF] = GXL_COMP;
 	char *dynbuf = 0;
 
 	ud->closedElementType = TAG_NONE;
 	if (ud->compositeReadState) {
-	    int len = sizeof(GXL_COMP) + agxblen(&ud->xml_attr_name);
+	    size_t len = sizeof(GXL_COMP) + agxblen(&ud->xml_attr_name);
 	    if (len <= SMALLBUF) {
-		name = buf;
+		new_name = buf;
 	    } else {
-		name = dynbuf = gcalloc(len, sizeof(char));
-		strcpy(name, GXL_COMP);
+		new_name = dynbuf = gcalloc(len, sizeof(char));
+		strcpy(new_name, GXL_COMP);
 	    }
-	    strcpy(name + sizeof(GXL_COMP) - 1,
+	    strcpy(new_name + sizeof(GXL_COMP) - 1,
 		   agxbuse(&ud->xml_attr_name));
 	    value = agxbuse(&ud->composite_buffer);
 	    agxbclear(&ud->xml_attr_value);
 	    ud->compositeReadState = FALSE;
 	} else {
-	    name = agxbuse(&ud->xml_attr_name);
+	    new_name = agxbuse(&ud->xml_attr_name);
 	    value = agxbuse(&ud->xml_attr_value);
 	}
 
 	switch (ud->globalAttrType) {
 	case TAG_NONE:
-	    setAttr(name, value, ud);
+	    setAttr(new_name, value, ud, false);
 	    break;
 	case TAG_NODE:
-	    setGlobalNodeAttr(G, name, value, ud);
+	    setGlobalNodeAttr(G, new_name, value);
 	    break;
 	case TAG_EDGE:
-	    setGlobalEdgeAttr(G, name, value, ud);
+	    setGlobalEdgeAttr(G, new_name, value);
 	    break;
 	case TAG_GRAPH:
-	    setGraphAttr(G, name, value, ud);
+	    setGraphAttr(G, new_name, value, ud);
+	    break;
+	case TAG_HTML_LIKE_STRING:
+	    setAttr(new_name, value, ud, true);
 	    break;
 	}
 	free(dynbuf);
@@ -656,29 +680,32 @@ static void endElementHandler(void *userData, const char *name)
 
 static void characterDataHandler(void *userData, const char *s, int length)
 {
-    userdata_t *ud = (userdata_t *) userData;
+    userdata_t *ud = userData;
+
+    assert(length >= 0 && "Expat returned negative length data");
+    size_t len = (size_t)length;
 
     if (!ud->listen)
 	return;
 
     if (ud->compositeReadState) {
-	agxbput_n(&ud->composite_buffer, (char *) s, length);
+	agxbput_n(&ud->composite_buffer, s, len);
 	return;
     }
 
-    agxbput_n(&ud->xml_attr_value, (char *) s, length);
+    agxbput_n(&ud->xml_attr_value, s, len);
 }
 
 Agraph_t *gxl_to_gv(FILE * gxlFile)
 {
-    char buf[BUFSIZE];
+    char buf[BUFSIZ];
     int done;
     userdata_t *udata = genUserdata();
     XML_Parser parser = XML_ParserCreate(NULL);
 
     if (udata == NULL) {
 	fprintf(stderr, "out of memory\n");
-	exit(1);
+	graphviz_exit(1);
     }
 
     XML_SetUserData(parser, udata);
@@ -692,16 +719,18 @@ Agraph_t *gxl_to_gv(FILE * gxlFile)
 	if (len == 0)
 	    break;
 	done = len < sizeof(buf);
-	if (XML_Parse(parser, buf, len, done) == XML_STATUS_ERROR) {
+	assert(len <= (size_t)INT_MAX && "too large data for Expat API");
+	if (XML_Parse(parser, buf, (int)len, done) == XML_STATUS_ERROR) {
 	    fprintf(stderr,
 		    "%s at line %lu\n",
 		    XML_ErrorString(XML_GetErrorCode(parser)),
 		    XML_GetCurrentLineNumber(parser));
-	    exit(1);
+	    graphviz_exit(1);
 	}
     } while (!done);
     XML_ParserFree(parser);
     freeUserdata(udata);
+    stack_reset(&Gstack);
 
     return root;
 }
