@@ -1,6 +1,3 @@
-/* $Id: pathaccess.c,v 1.5 2011/01/25 16:30:47 ellson Exp $ $Revision: 1.5 $ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*
@@ -22,23 +19,17 @@
  * path returned in path buffer
  */
 
-#include <ast.h>
-#ifdef HAVE_UNISTD_H
+#include <ast/ast.h>
 #include <unistd.h>
-#else
-#include <compat_unistd.h>
-#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 
-/* #include <ls.h> */
+char *pathcanon(char *path);
 
-char *pathcanon(char *path, int flags);
-
-char *pathaccess(register char *path, register const char *dirs,
-		 const char *a, const char *b, register int mode)
+char *pathaccess(char *path, const char *dirs,
+		 const char *a, const char *b, int mode)
 {
-    register int m = 0;
+    int m = 0;
     int sep = ':';
     char cwd[PATH_MAX];
     struct stat st;
@@ -62,7 +53,7 @@ char *pathaccess(register char *path, register const char *dirs,
     }
     do {
 	dirs = pathcat(path, dirs, sep, a, b);
-	pathcanon(path, 0);
+	pathcanon(path);
 	if (!access(path, m)) {
 	    if ((mode & PATH_REGULAR)
 		&& (stat(path, &st) || S_ISDIR(st.st_mode)))
