@@ -32,9 +32,6 @@
 #include		<stdbool.h>
 #include		<stdlib.h>
 #include		<string.h>
-#ifdef HAVE_UNISTD_H
-#include	<unistd.h>
-#endif				/* HAVE_UNISTD_H */
 #include <assert.h>
 #include <stdint.h>
 
@@ -50,8 +47,6 @@ static inline bool streq(const char *a, const char *b) {
 #define AGCLOS(g,d)			((g)->clos->state.d)
 #define AGNEW(g,t)			((t*)(agalloc(g,sizeof(t))))
 
-#define ISALNUM(c) ((isalnum(c)) || ((c) == '_') || (!isascii(c)))
-
 	/* functional definitions */
 typedef Agobj_t *(*agobjsearchfn_t) (Agraph_t * g, Agobj_t * obj);
 CGHDR_API int agapply(Agraph_t * g, Agobj_t * obj, agobjfn_t fn, void *arg,
@@ -110,7 +105,7 @@ void aglexbad(void);
 
 	/* ID management */
 int agmapnametoid(Agraph_t * g, int objtype, char *str,
-          IDTYPE *result, int allocflag);
+          IDTYPE *result, int createflag);
 int agallocid(Agraph_t * g, int objtype, IDTYPE request);
 void agfreeid(Agraph_t * g, int objtype, IDTYPE id);
 char *agprintid(Agobj_t * obj);
@@ -127,7 +122,6 @@ void agregister(Agraph_t * g, int objtype, void *obj);
 void agedgesetop(Agraph_t * g, Agedge_t * e, int insertion);
 void agdelnodeimage(Agraph_t * g, Agnode_t * node, void *ignored);
 void agdeledgeimage(Agraph_t * g, Agedge_t * edge, void *ignored);
-void *agrebind0(Agraph_t * g, void *obj);	/* unsafe */
 CGHDR_API int agrename(Agobj_t * obj, char *newname);
 void agrecclose(Agobj_t * obj);
 
