@@ -236,7 +236,7 @@ void arrow_flags(Agedge_t * e, int *sflag, int *eflag)
     }
 }
 
-double arrow_length(edge_t * e, int flag)
+static double arrow_length(edge_t * e, int flag)
 {
     double lenfact = 0.0;
     int f, i;
@@ -272,7 +272,8 @@ int arrowEndClip(edge_t* e, pointf * ps, int startp,
 
     elen = arrow_length(e, eflag);
     elen2 = elen * elen;
-    spl->eflag = eflag, spl->ep = ps[endp + 3];
+    spl->eflag = eflag;
+    spl->ep = ps[endp + 3];
     if (endp > startp && DIST2(ps[endp], ps[endp + 3]) < elen2) {
 	endp -= 3;
     }
@@ -301,7 +302,8 @@ int arrowStartClip(edge_t* e, pointf * ps, int startp,
 
     slen = arrow_length(e, sflag);
     slen2 = slen * slen;
-    spl->sflag = sflag, spl->sp = ps[startp];
+    spl->sflag = sflag;
+    spl->sp = ps[startp];
     if (endp > startp && DIST2(ps[startp], ps[startp + 3]) < slen2) {
 	startp += 3;
     }
