@@ -325,8 +325,7 @@ static pitem* addRow (void)
 /* setCell:
  * Set cell body and type and attach to row
  */
-static void setCell (htmlcell_t* cp, void* obj, int kind)
-{
+static void setCell(htmlcell_t *cp, void *obj, char kind) {
   pitem*     sp = NEW(pitem);
   htmltbl_t* tbl = HTMLstate.tblstack;
   pitem*     rp = dtlast (tbl->u.p.rows);
@@ -338,25 +337,24 @@ static void setCell (htmlcell_t* cp, void* obj, int kind)
     cp->ruled = HTML_VRULE;
   
   if(kind == HTML_TEXT)
-  	cp->child.u.txt = (htmltxt_t*)obj;
+  	cp->child.u.txt = obj;
   else if (kind == HTML_IMAGE)
-    cp->child.u.img = (htmlimg_t*)obj;
+    cp->child.u.img = obj;
   else
-    cp->child.u.tbl = (htmltbl_t*)obj;
+    cp->child.u.tbl = obj;
 }
 
 /* mkLabel:
  * Create label, given body and type.
  */
-static htmllabel_t* mkLabel (void* obj, int kind)
-{
+static htmllabel_t *mkLabel(void *obj, char kind) {
   htmllabel_t* lp = NEW(htmllabel_t);
 
   lp->kind = kind;
   if (kind == HTML_TEXT)
-    lp->u.txt = (htmltxt_t*)obj;
+    lp->u.txt = obj;
   else
-    lp->u.tbl = (htmltbl_t*)obj;
+    lp->u.tbl = obj;
   return lp;
 }
 
@@ -461,7 +459,7 @@ popFont (void)
 }
 
 
-#line 465 "htmlparse.c" /* yacc.c:339  */
+#line 463 "htmlparse.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -589,7 +587,7 @@ extern int htmldebug;
 
 union HTMLSTYPE
 {
-#line 409 "../../lib/common/htmlparse.y" /* yacc.c:355  */
+#line 407 "../../lib/common/htmlparse.y" /* yacc.c:355  */
 
   int    i;
   htmltxt_t*  txt;
@@ -599,7 +597,7 @@ union HTMLSTYPE
   htmlimg_t*   img;
   pitem*       p;
 
-#line 603 "htmlparse.c" /* yacc.c:355  */
+#line 601 "htmlparse.c" /* yacc.c:355  */
 };
 
 typedef union HTMLSTYPE HTMLSTYPE;
@@ -616,7 +614,7 @@ int htmlparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 620 "htmlparse.c" /* yacc.c:358  */
+#line 618 "htmlparse.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -917,13 +915,13 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   441,   441,   442,   443,   446,   449,   450,   453,   454,
-     455,   456,   457,   458,   459,   460,   461,   462,   465,   468,
-     471,   474,   477,   480,   483,   486,   489,   492,   495,   498,
-     501,   504,   507,   510,   513,   514,   517,   518,   521,   521,
-     542,   543,   544,   545,   546,   547,   550,   551,   554,   555,
-     556,   559,   559,   562,   563,   564,   567,   567,   568,   568,
-     569,   569,   570,   570,   573,   574,   577,   578,   581,   582
+       0,   439,   439,   440,   441,   444,   447,   448,   451,   452,
+     453,   454,   455,   456,   457,   458,   459,   460,   463,   466,
+     469,   472,   475,   478,   481,   484,   487,   490,   493,   496,
+     499,   502,   505,   508,   511,   512,   515,   516,   519,   519,
+     540,   541,   542,   543,   544,   545,   548,   549,   552,   553,
+     554,   557,   557,   560,   561,   562,   565,   565,   566,   566,
+     567,   567,   568,   568,   571,   572,   575,   576,   579,   580
 };
 #endif
 
@@ -1808,151 +1806,151 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 441 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 439 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { HTMLstate.lbl = mkLabel((yyvsp[-1].txt),HTML_TEXT); }
-#line 1814 "htmlparse.c" /* yacc.c:1646  */
+#line 1812 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 442 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 440 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { HTMLstate.lbl = mkLabel((yyvsp[-1].tbl),HTML_TBL); }
-#line 1820 "htmlparse.c" /* yacc.c:1646  */
+#line 1818 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 443 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 441 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { cleanup(); YYABORT; }
-#line 1826 "htmlparse.c" /* yacc.c:1646  */
+#line 1824 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 446 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 444 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.txt) = mkText(); }
-#line 1832 "htmlparse.c" /* yacc.c:1646  */
+#line 1830 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 453 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 451 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { appendFItemList(HTMLstate.str);}
-#line 1838 "htmlparse.c" /* yacc.c:1646  */
+#line 1836 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 454 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 452 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {appendFLineList((yyvsp[0].i));}
-#line 1844 "htmlparse.c" /* yacc.c:1646  */
+#line 1842 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 465 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 463 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { pushFont ((yyvsp[0].font)); }
-#line 1850 "htmlparse.c" /* yacc.c:1646  */
+#line 1848 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 468 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 466 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { popFont (); }
-#line 1856 "htmlparse.c" /* yacc.c:1646  */
+#line 1854 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 471 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 469 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1862 "htmlparse.c" /* yacc.c:1646  */
+#line 1860 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 474 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 472 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1868 "htmlparse.c" /* yacc.c:1646  */
+#line 1866 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 477 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 475 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1874 "htmlparse.c" /* yacc.c:1646  */
+#line 1872 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 480 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 478 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1880 "htmlparse.c" /* yacc.c:1646  */
+#line 1878 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 483 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 481 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1886 "htmlparse.c" /* yacc.c:1646  */
+#line 1884 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 486 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 484 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1892 "htmlparse.c" /* yacc.c:1646  */
+#line 1890 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 489 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 487 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1898 "htmlparse.c" /* yacc.c:1646  */
+#line 1896 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 492 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 490 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1904 "htmlparse.c" /* yacc.c:1646  */
+#line 1902 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 495 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 493 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1910 "htmlparse.c" /* yacc.c:1646  */
+#line 1908 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 498 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 496 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1916 "htmlparse.c" /* yacc.c:1646  */
+#line 1914 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 501 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 499 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1922 "htmlparse.c" /* yacc.c:1646  */
+#line 1920 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 504 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 502 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1928 "htmlparse.c" /* yacc.c:1646  */
+#line 1926 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 507 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 505 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {pushFont((yyvsp[0].font));}
-#line 1934 "htmlparse.c" /* yacc.c:1646  */
+#line 1932 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 510 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 508 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {popFont();}
-#line 1940 "htmlparse.c" /* yacc.c:1646  */
+#line 1938 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 513 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 511 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-1].i); }
-#line 1946 "htmlparse.c" /* yacc.c:1646  */
+#line 1944 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 514 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 512 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[0].i); }
-#line 1952 "htmlparse.c" /* yacc.c:1646  */
+#line 1950 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 521 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 519 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { 
           if (nonSpace(agxbuse(HTMLstate.str))) {
             htmlerror ("Syntax error: non-space string used before <TABLE>");
@@ -1964,11 +1962,11 @@ yyreduce:
           (yyvsp[0].tbl)->font = HTMLstate.fontstack->cfont;
           (yyval.tbl) = (yyvsp[0].tbl);
         }
-#line 1968 "htmlparse.c" /* yacc.c:1646  */
+#line 1966 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 532 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 530 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     {
           if (nonSpace(agxbuse(HTMLstate.str))) {
             htmlerror ("Syntax error: non-space string used after </TABLE>");
@@ -1977,155 +1975,155 @@ yyreduce:
           (yyval.tbl) = HTMLstate.tblstack;
           HTMLstate.tblstack = HTMLstate.tblstack->u.p.prev;
         }
-#line 1981 "htmlparse.c" /* yacc.c:1646  */
+#line 1979 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 542 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 540 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.tbl) = (yyvsp[0].tbl); }
-#line 1987 "htmlparse.c" /* yacc.c:1646  */
+#line 1985 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 543 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 541 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 1993 "htmlparse.c" /* yacc.c:1646  */
+#line 1991 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 42:
-#line 544 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 542 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 1999 "htmlparse.c" /* yacc.c:1646  */
+#line 1997 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 43:
-#line 545 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 543 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2005 "htmlparse.c" /* yacc.c:1646  */
+#line 2003 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 546 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 544 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2011 "htmlparse.c" /* yacc.c:1646  */
+#line 2009 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 547 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 545 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2017 "htmlparse.c" /* yacc.c:1646  */
+#line 2015 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 48:
-#line 554 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 552 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.p) = (yyvsp[0].p); }
-#line 2023 "htmlparse.c" /* yacc.c:1646  */
+#line 2021 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 555 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 553 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.p) = (yyvsp[0].p); }
-#line 2029 "htmlparse.c" /* yacc.c:1646  */
+#line 2027 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 556 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 554 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyvsp[-2].p)->ruled = 1; (yyval.p) = (yyvsp[0].p); }
-#line 2035 "htmlparse.c" /* yacc.c:1646  */
+#line 2033 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 559 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 557 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { addRow (); }
-#line 2041 "htmlparse.c" /* yacc.c:1646  */
+#line 2039 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 559 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 557 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.p) = lastRow(); }
-#line 2047 "htmlparse.c" /* yacc.c:1646  */
+#line 2045 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 562 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 560 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.cell) = (yyvsp[0].cell); }
-#line 2053 "htmlparse.c" /* yacc.c:1646  */
+#line 2051 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 563 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 561 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.cell) = (yyvsp[0].cell); }
-#line 2059 "htmlparse.c" /* yacc.c:1646  */
+#line 2057 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 564 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 562 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyvsp[-2].cell)->ruled |= HTML_VRULE; (yyval.cell) = (yyvsp[0].cell); }
-#line 2065 "htmlparse.c" /* yacc.c:1646  */
+#line 2063 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 567 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 565 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { setCell((yyvsp[-1].cell),(yyvsp[0].tbl),HTML_TBL); }
-#line 2071 "htmlparse.c" /* yacc.c:1646  */
+#line 2069 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 567 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 565 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.cell) = (yyvsp[-3].cell); }
-#line 2077 "htmlparse.c" /* yacc.c:1646  */
+#line 2075 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 568 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 566 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { setCell((yyvsp[-1].cell),(yyvsp[0].txt),HTML_TEXT); }
-#line 2083 "htmlparse.c" /* yacc.c:1646  */
+#line 2081 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 568 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 566 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.cell) = (yyvsp[-3].cell); }
-#line 2089 "htmlparse.c" /* yacc.c:1646  */
+#line 2087 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 569 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 567 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { setCell((yyvsp[-1].cell),(yyvsp[0].img),HTML_IMAGE); }
-#line 2095 "htmlparse.c" /* yacc.c:1646  */
+#line 2093 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 569 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 567 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.cell) = (yyvsp[-3].cell); }
-#line 2101 "htmlparse.c" /* yacc.c:1646  */
+#line 2099 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 570 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 568 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { setCell((yyvsp[0].cell),mkText(),HTML_TEXT); }
-#line 2107 "htmlparse.c" /* yacc.c:1646  */
+#line 2105 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 63:
-#line 570 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 568 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.cell) = (yyvsp[-2].cell); }
-#line 2113 "htmlparse.c" /* yacc.c:1646  */
+#line 2111 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 64:
-#line 573 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 571 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.img) = (yyvsp[-1].img); }
-#line 2119 "htmlparse.c" /* yacc.c:1646  */
+#line 2117 "htmlparse.c" /* yacc.c:1646  */
     break;
 
   case 65:
-#line 574 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
+#line 572 "../../lib/common/htmlparse.y" /* yacc.c:1646  */
     { (yyval.img) = (yyvsp[0].img); }
-#line 2125 "htmlparse.c" /* yacc.c:1646  */
+#line 2123 "htmlparse.c" /* yacc.c:1646  */
     break;
 
 
-#line 2129 "htmlparse.c" /* yacc.c:1646  */
+#line 2127 "htmlparse.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2353,7 +2351,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 586 "../../lib/common/htmlparse.y" /* yacc.c:1906  */
+#line 584 "../../lib/common/htmlparse.y" /* yacc.c:1906  */
 
 
 /* parseHTML:
@@ -2363,7 +2361,7 @@ yyreturn:
 htmllabel_t*
 parseHTML (char* txt, int* warn, htmlenv_t *env)
 {
-  unsigned char buf[SMALLBUF];
+  char buf[SMALLBUF];
   agxbuf        str;
   htmllabel_t*  l;
   sfont_t       dfltf;
