@@ -35,8 +35,11 @@
 #include <common/pointset.h>
 #include <common/intset.h>
 #include <cdt/cdt.h>
+#include <cgraph/itos.h>
 #include <cgraph/strcasecmp.h>
 #include <stddef.h>
+#include <stdbool.h>
+#include <stdio.h>
 
 #define DEFAULT_BORDER    1
 #define DEFAULT_CELLPADDING  2
@@ -47,7 +50,7 @@ typedef struct {
     char *tooltip;
     char *target;
     char *id;
-    boolean explicit_tooltip;
+    bool explicit_tooltip;
     point LL;
     point UR;
 } htmlmap_data_t;
@@ -377,19 +380,19 @@ initAnchor(GVJ_t * job, htmlenv_t * env, htmldata_t * data, boxf b,
     static int anchorId;
     int internalId = 0;
     agxbuf xb;
-    unsigned char buf[SMALLBUF];
+    char buf[SMALLBUF];
 
     save->url = obj->url;
     save->tooltip = obj->tooltip;
     save->target = obj->target;
     save->id = obj->id;
-    save->explicit_tooltip = obj->explicit_tooltip;
+    save->explicit_tooltip = obj->explicit_tooltip != 0;
     id = data->id;
     if (!id || !*id) {		/* no external id, so use the internal one */
 	agxbinit(&xb, SMALLBUF, buf);
 	if (!env->objid) {
 	    env->objid = strdup(getObjId(job, obj->u.n, &xb));
-	    env->objid_set = 1;
+	    env->objid_set = true;
 	}
 	agxbprint(&xb, "%s_%d", env->objid, anchorId++);
 	id = agxbuse(&xb);
@@ -618,7 +621,7 @@ static void emit_html_img(GVJ_t * job, htmlimg_t * cp, htmlenv_t * env)
 	scale = env->imgscale;
     assert(cp->src);
     assert(cp->src[0]);
-    gvrender_usershape(job, cp->src, A, 4, TRUE, scale, "mc");
+    gvrender_usershape(job, cp->src, A, 4, true, scale, "mc");
 }
 
 static void emit_html_cell(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env)
@@ -765,7 +768,7 @@ void emit_html_label(GVJ_t * job, htmllabel_t * lp, textlabel_t * tp)
     env.finfo.size = tp->fontsize;
     env.imgscale = agget(job->obj->u.n, "imagescale");
     env.objid = job->obj->id;
-    env.objid_set = 0;
+    env.objid_set = false;
     if ((env.imgscale == NULL) || (env.imgscale[0] == '\0'))
 	env.imgscale = "false";
     if (lp->kind == HTML_TBL) {
@@ -937,64 +940,6 @@ boxf *html_port(node_t * n, char *pname, int *sides)
 
 }
 
-/* html_path:
- * Return a box in a table containing the given endpoint.
- * If the top flow is text (no internal structure), return 
- * the box of the flow
- * Else return the box of the subtable containing the point.
- * Because of spacing, the point might not be in any subtable.
- * In that case, return the top flow's box.
- * Note that box[0] must contain the edge point. Additional boxes
- * move out to the boundary.
- *
- * At present, unimplemented, since the label may be inside a
- * non-box node and we need to figure out what this means.
- */
-int html_path(node_t * n, port * p, int side, boxf * rv, int *k)
-{
-#ifdef UNIMPL
-    point p;
-    tbl_t *info;
-    tbl_t *t;
-    boxf b;
-    int i;
-
-    info = (tbl_t *) ND_shape_info(n);
-    assert(info->tbls);
-    info = info->tbls[0];	/* top-level flow */
-    assert(IS_FLOW(info));
-
-    b = info->box;
-    if (info->tbl) {
-	info = info->tbl;
-	if (pt == 1)
-	    p = ED_tail_port(e).p;
-	else
-	    p = ED_head_port(e).p;
-	p = flip_pt(p, GD_rankdir(n->graph));	/* move p to node's coordinate system */
-	for (i = 0; (t = info->tbls[i]) != 0; i++)
-	    if (INSIDE(p, t->box)) {
-		b = t->box;
-		break;
-	    }
-    }
-
-    /* move box into layout coordinate system */
-    if (GD_flip(n->graph))
-	b = flip_trans_box(b, ND_coord_i(n));
-    else
-	b = move_box(b, ND_coord_i(n));
-
-    *k = 1;
-    *rv = b;
-    if (pt == 1)
-	return BOTTOM;
-    else
-	return TOP;
-#endif
-    return 0;
-}
-
 static int size_html_txt(GVC_t *gvc, htmltxt_t * ftxt, htmlenv_t * env)
 {
     double xsize = 0.0;		/* width of text block */
@@ -1007,19 +952,19 @@ static int size_html_txt(GVC_t *gvc, htmltxt_t * ftxt, htmlenv_t * env)
     double width;
     textspan_t lp;
     textfont_t tf = {NULL,NULL,NULL,0.0,0,0};
-    double maxoffset, mxysize;
-    int simple = 1;              /* one item per span, same font size/face, no flags */
+    double maxoffset, mxysize = 0.0;
+    bool simple = true; // one item per span, same font size/face, no flags
     double prev_fsize = -1;
     char* prev_fname = NULL;
 
     for (i = 0; i < ftxt->nspans; i++) {
 	if (ftxt->spans[i].nitems > 1) {
-	    simple = 0;
+	    simple = false;
 	    break;
 	}
 	if (ftxt->spans[i].items[0].font) {
 	    if (ftxt->spans[i].items[0].font->flags) {
-		simple = 0;
+		simple = false;
 		break;
 	    }
 	    if (ftxt->spans[i].items[0].font->size > 0)
@@ -1038,13 +983,13 @@ static int size_html_txt(GVC_t *gvc, htmltxt_t * ftxt, htmlenv_t * env)
 	if (prev_fsize == -1)
 	    prev_fsize = tf.size;
 	else if (tf.size != prev_fsize) {
-	    simple = 0;
+	    simple = false;
 	    break;
 	}
 	if (prev_fname == NULL)
 	    prev_fname = tf.name;
 	else if (strcmp(tf.name,prev_fname)) {
-	    simple = 0;
+	    simple = false;
 	    break;
 	}
     }
@@ -1151,7 +1096,7 @@ static int size_html_img(htmlimg_t * img, htmlenv_t * env)
 	agerr(AGERR, "No or improper image file=\"%s\"\n", img->src);
     } else {
 	rv = 0;
-	GD_has_images(env->g) = TRUE;
+	GD_has_images(env->g) = true;
     }
 
     B2BF(b, img->box);
@@ -1255,7 +1200,6 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
     pitem *rp;
     pitem *cp;
     Dt_t *cdict;
-    int r, c;
     htmlcell_t *cellp;
     htmlcell_t **cells;
     Dt_t *rows = tbl->u.p.rows;
@@ -1267,7 +1211,7 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
 
     rp = (pitem *) dtflatten(rows);
     size_t cnt = 0;
-    r = 0;
+    unsigned short r = 0;
     while (rp) {
 	cdict = rp->u.rp;
 	cp = (pitem *) dtflatten(cdict);
@@ -1289,7 +1233,7 @@ static int processTbl(graph_t * g, htmltbl_t * tbl, htmlenv_t * env)
     while (rp) {
 	cdict = rp->u.rp;
 	cp = (pitem *) dtflatten(cdict);
-	c = 0;
+	unsigned short c = 0;
 	while (cp) {
 	    cellp = cp->u.cp;
 	    *cells++ = cellp;
@@ -1361,25 +1305,6 @@ static void sizeLinearArray(htmltbl_t * tbl)
     }
 }
 
-static char *nnames[] = {
-    "0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
-    "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20",
-};
-
-/* nToName:
- * Convert int to its decimal string representation.
- */
-static char *nToName(int c)
-{
-    static char name[100];
-
-    if (c < sizeof(nnames) / sizeof(char *))
-	return nnames[c];
-
-    snprintf(name, sizeof(name), "%d", c);
-    return name;
-}
-
 /* closeGraphs:
  * Clean up graphs made for setting column and row widths.
  */
@@ -1408,7 +1333,7 @@ static void checkChain(graph_t * g)
     for (h = ND_next(t); h; h = ND_next(h)) {
 	if (!agfindedge(g, t, h)) {
 	    e = agedge(g, t, h, NULL, 1);
-	    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);
+	    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
 	    ED_minlen(e) = 0;
 	    elist_append(e, ND_out(t));
 	    elist_append(e, ND_in(h));
@@ -1431,7 +1356,7 @@ checkEdge (graph_t* g, node_t* t, node_t* h, int sz)
 	ED_minlen(e) = MAX(ED_minlen(e), sz);
     else {
 	e = agedge(g, t, h, NULL, 1);
-	agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);
+	agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
 	ED_minlen(e) = sz;
 	elist_append(e, ND_out(t));
 	elist_append(e, ND_in(h));
@@ -1455,11 +1380,13 @@ static void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
     node_t *lastn;
     node_t *h;
     int i;
+    char value_buffer[CHARS_FOR_NUL_TERM_INT];
 
     lastn = NULL;
     for (i = 0; i <= tbl->cc; i++) {
-	t = agnode(colg, nToName(i), 1);
-	agbindrec(t, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
+	snprintf(value_buffer, sizeof(value_buffer), "%d", i);
+	t = agnode(colg, value_buffer, 1);
+	agbindrec(t, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
 	alloc_elist(tbl->rc, ND_in(t));
 	alloc_elist(tbl->rc, ND_out(t));
 	if (lastn) {
@@ -1471,8 +1398,9 @@ static void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
     }
     lastn = NULL;
     for (i = 0; i <= tbl->rc; i++) {
-	t = agnode(rowg, nToName(i), 1);
-	agbindrec(t, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
+	snprintf(value_buffer, sizeof(value_buffer), "%d", i);
+	t = agnode(rowg, value_buffer, 1);
+	agbindrec(t, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
 	alloc_elist(tbl->cc, ND_in(t));
 	alloc_elist(tbl->cc, ND_out(t));
 	if (lastn) {
@@ -1485,12 +1413,16 @@ static void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
 
     for (cells = tbl->u.n.cells; *cells; cells++) {
 	cp = *cells;
-	t = agfindnode(colg, nToName(cp->col));
-	h = agfindnode(colg, nToName(cp->col + cp->cspan));
+	snprintf(value_buffer, sizeof(value_buffer), "%d", cp->col);
+	t = agfindnode(colg, value_buffer);
+	snprintf(value_buffer, sizeof(value_buffer), "%d", cp->col + cp->cspan);
+	h = agfindnode(colg, value_buffer);
 	checkEdge (colg, t, h, cp->data.box.UR.x);
 
-	t = agfindnode(rowg, nToName(cp->row));
-	h = agfindnode(rowg, nToName(cp->row + cp->rspan));
+	snprintf(value_buffer, sizeof(value_buffer), "%d", cp->row);
+	t = agfindnode(rowg, value_buffer);
+	snprintf(value_buffer, sizeof(value_buffer), "%d", cp->row + cp->rspan);
+	h = agfindnode(rowg, value_buffer);
 	checkEdge (rowg, t, h, cp->data.box.UR.y);
     }
 
@@ -1554,8 +1486,8 @@ static void sizeArray(htmltbl_t * tbl)
     rowg = agopen("rowg", dir, NULL);
     colg = agopen("colg", dir, NULL);
     /* Only need GD_nlist */
-    agbindrec(rowg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);	// graph custom data
-    agbindrec(colg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);	// graph custom data
+    agbindrec(rowg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);	// graph custom data
+    agbindrec(colg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);	// graph custom data
     makeGraphs(tbl, rowg, colg);
     rank(rowg, 2, INT_MAX);
     rank(colg, 2, INT_MAX);
@@ -1894,10 +1826,10 @@ static char *nameOf(void *obj, agxbuf * xb)
     Agedge_t *ep;
     switch (agobjkind(obj)) {
     case AGRAPH:
-	agxbput(xb, agnameof(((Agraph_t *) obj)));
+	agxbput(xb, agnameof(obj));
 	break;
     case AGNODE:
-	agxbput(xb, agnameof(((Agnode_t *) obj)));
+	agxbput(xb, agnameof(obj));
 	break;
     case AGEDGE:
 	ep = (Agedge_t *) obj;
@@ -2064,7 +1996,7 @@ int make_html_label(void *obj, textlabel_t * lp)
 	env.g = ((Agraph_t *) obj)->root;
 	break;
     case AGNODE:
-	env.g = agraphof(((Agnode_t *) obj));
+	env.g = agraphof(obj);
 	break;
     case AGEDGE:
 	env.g = agraphof(aghead(((Agedge_t *) obj)));
@@ -2080,9 +2012,9 @@ int make_html_label(void *obj, textlabel_t * lp)
     if (!lbl) {
 	/* Parse of label failed; revert to simple text label */
 	agxbuf xb;
-	unsigned char buf[SMALLBUF];
+	char buf[SMALLBUF];
 	agxbinit(&xb, SMALLBUF, buf);
-	lp->html = FALSE;
+	lp->html = false;
 	lp->text = strdup(nameOf(obj, &xb));
 	switch (lp->charset) {
 	case CHAR_LATIN1:
