@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,23 +5,16 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GV_LOGIC_H
-#define GV_LOGIC_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#if defined HAVE_STDBOOL_H && ! defined __cplusplus
 #include <stdbool.h>
-#endif
-
-#ifndef NOT
-#define NOT(v) (!(v))
-#endif
 
 #ifndef FALSE
 #define	FALSE (0)
@@ -33,21 +23,6 @@ extern "C" {
 #define TRUE (!FALSE)
 #endif
 
-#ifndef NOTUSED
-#define NOTUSED(var) (void) var
-#endif
-
-#ifndef NULL
-#define NULL (void *)0
-#endif
-
-#ifndef NIL
-#define NIL(type) ((type)0)
-#endif
-
 #ifdef __cplusplus
 }
 #endif
-
-#endif
-
