@@ -114,7 +114,7 @@ typedef struct {
 
 static void adjustregularpath(path *, int, int);
 static Agedge_t *bot_bound(Agedge_t *, int);
-static boolean pathscross(Agnode_t *, Agnode_t *, Agedge_t *, Agedge_t *);
+static bool pathscross(Agnode_t *, Agnode_t *, Agedge_t *, Agedge_t *);
 static Agraph_t *cl_bound(graph_t*, Agnode_t *, Agnode_t *);
 static int cl_vninside(Agraph_t *, Agnode_t *);
 static void completeregularpath(path *, Agedge_t *, Agedge_t *,
@@ -147,23 +147,23 @@ getmainedge(edge_t * e)
     return le;
 }
 
-static boolean spline_merge(node_t * n)
+static bool spline_merge(node_t * n)
 {
     return ND_node_type(n) == VIRTUAL
 	    && (ND_in(n).size > 1 || ND_out(n).size > 1);
 }
 
-static boolean swap_ends_p(edge_t * e)
+static bool swap_ends_p(edge_t * e)
 {
     while (ED_to_orig(e))
 	e = ED_to_orig(e);
     if (ND_rank(aghead(e)) > ND_rank(agtail(e)))
-	return FALSE;
+	return false;
     if (ND_rank(aghead(e)) < ND_rank(agtail(e)))
-	return TRUE;
+	return true;
     if (ND_order(aghead(e)) >= ND_order(agtail(e)))
-	return FALSE;
-    return TRUE;
+	return false;
+    return true;
 }
 
 static splineInfo sinfo = {.swapEnds = swap_ends_p,
@@ -171,9 +171,9 @@ static splineInfo sinfo = {.swapEnds = swap_ends_p,
 
 int portcmp(port p0, port p1)
 {
-    if (p1.defined == FALSE)
+    if (!p1.defined)
 	return p0.defined ? 1 : 0;
-    if (p0.defined == FALSE)
+    if (!p0.defined)
 	return -1;
     if (p0.p.x < p1.p.x)
 	return -1;
@@ -294,7 +294,7 @@ setEdgeLabelPos (graph_t * g)
 		l = ED_label(fe);
 		assert (l);
 		l->pos = ND_coord(n);
-		l->set = TRUE;
+		l->set = true;
 	    }
 	    else if ((l = ND_label(n))) {// label of regular edge
 		place_vnlabel(n);
@@ -324,15 +324,15 @@ static void _dot_splines(graph_t * g, int normalize)
     fwdedgea.out.base.data = (Agrec_t*)&fwdedgeai;
     fwdedgeb.out.base.data = (Agrec_t*)&fwdedgebi;
 
-    if (et == ET_NONE) return; 
-    if (et == ET_CURVED) {
+    if (et == EDGETYPE_NONE) return;
+    if (et == EDGETYPE_CURVED) {
 	resetRW (g);
 	if (GD_has_labels(g->root) & EDGE_LABEL) {
 	    agerr (AGWARN, "edge labels with splines=curved not supported in dot - use xlabels\n");
 	}
     } 
 #ifdef ORTHO
-    if (et == ET_ORTHO) {
+    if (et == EDGETYPE_ORTHO) {
 	resetRW (g);
 	if (GD_has_labels(g->root) & EDGE_LABEL) {
 	    setEdgeLabelPos (g);
@@ -375,9 +375,9 @@ static void _dot_splines(graph_t * g, int normalize)
 		edge_t* fe = (edge_t*)ND_alg(n);
 		assert (ED_label(fe));
 		ED_label(fe)->pos = ND_coord(n);
-		ED_label(fe)->set = TRUE;
+		ED_label(fe)->set = true;
 	    }
-	    if (ND_node_type(n) != NORMAL && sinfo.splineMerge(n) == FALSE)
+	    if (ND_node_type(n) != NORMAL && !sinfo.splineMerge(n))
 		continue;
 	    for (k = 0; (e = ND_out(n).list[k]); k++) {
 		if (ED_edge_type(e) == FLATORDER || ED_edge_type(e) == IGNORED)
@@ -427,7 +427,7 @@ static void _dot_splines(graph_t * g, int normalize)
     P->boxes = N_NEW(n_nodes + 20 * 2 * NSUB, boxf);
     sd.Rank_box = N_NEW(i, boxf);
 
-    if (et == ET_LINE) {
+    if (et == EDGETYPE_LINE) {
     /* place regular edge labels */
 	for (n = GD_nlist(g); n; n = ND_next(n)) {
 	    if (ND_node_type(n) == VIRTUAL && ND_label(n)) {
@@ -472,7 +472,7 @@ static void _dot_splines(graph_t * g, int normalize)
 		break;
 	}
 
-	if (et == ET_CURVED) {
+	if (et == EDGETYPE_CURVED) {
 	    int ii;
 	    edge_t* e0;
 	    edge_t** edgelist;
@@ -505,7 +505,7 @@ static void _dot_splines(graph_t * g, int normalize)
 		int dwny = ND_coord(n).y - ND_coord(GD_rank(g)[r+1].v[0]).y;
 		sizey = MIN(upy, dwny);
 	    }
-	    makeSelfEdge(P, edges, ind, cnt, sd.Multisep, sizey/2, &sinfo);
+	    makeSelfEdge(edges, ind, cnt, sd.Multisep, sizey / 2, &sinfo);
 	    for (b = 0; b < cnt; b++) {
 		e = edges[ind+b];
 		if (ED_label(e))
@@ -542,7 +542,7 @@ finish :
 	    if (E_headlabel) {
 		for (e = agfstin(g, n); e; e = agnxtin(g, e))
 		    if (ED_head_label(AGMKOUT(e))) {
-			place_portlabel(AGMKOUT(e), TRUE);
+			place_portlabel(AGMKOUT(e), true);
 			updateBB(g, ED_head_label(AGMKOUT(e)));
 		    }
 
@@ -550,7 +550,7 @@ finish :
 	    if (E_taillabel) {
 		for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
 		    if (ED_tail_label(e)) {
-			if (place_portlabel(e, FALSE))
+			if (place_portlabel(e, false))
 			    updateBB(g, ED_tail_label(e));
 		    }
 		}
@@ -560,9 +560,9 @@ finish :
     /* end vladimir */
 
 #ifdef ORTHO
-    if (et != ET_ORTHO && et != ET_CURVED)  {
+    if (et != EDGETYPE_ORTHO && et != EDGETYPE_CURVED)  {
 #else
-    if (et != ET_CURVED) {
+    if (et != EDGETYPE_CURVED) {
 #endif
 	free(edges);
 	free(P->boxes);
@@ -600,7 +600,7 @@ place_vnlabel(node_t * n)
     width = GD_flip(agraphof(n)) ? dimen.y : dimen.x;
     ED_label(e)->pos.x = ND_coord(n).x + width / 2.0;
     ED_label(e)->pos.y = ND_coord(n).y;
-    ED_label(e)->set = TRUE;
+    ED_label(e)->set = true;
 }
 
 static void 
@@ -856,7 +856,7 @@ cloneGraph (graph_t* g, attr_state_t* attr_state)
 	auxg = agopen ("auxg",Agdirected, NULL);
     else
 	auxg = agopen ("auxg",Agundirected, NULL);
-    agbindrec(auxg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+    agbindrec(auxg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     agattr(auxg, AGRAPH, "rank", "");
     GD_drawing(auxg) = NEW(layout_t);
     GD_drawing(auxg)->quantum = GD_drawing(g)->quantum; 
@@ -950,7 +950,7 @@ static node_t*
 cloneNode (graph_t* g, node_t* orign, int flipped)
 {
     node_t* n = agnode(g, agnameof(orign),1);
-    agbindrec(n, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
+    agbindrec(n, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
     agcopyattr (orign, n);
     if (shapeOf(orign) == SH_RECORD) {
 	int lbllen = strlen(ND_label(orign)->text);
@@ -968,7 +968,7 @@ static edge_t*
 cloneEdge (graph_t* g, node_t* tn, node_t* hn, edge_t* orig)
 {
     edge_t* e = agedge(g, tn, hn,NULL,1);
-    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);
+    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
     agcopyattr (orig, e);
 
     return e;
@@ -1033,7 +1033,6 @@ static int edgelblcmpfn(edge_t** ptr0, edge_t** ptr1)
 static void
 makeSimpleFlatLabels (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt, int et, int n_lbls)
 {
-    pointf *ps;
     Ppoly_t poly;
     int pn;
     edge_t* e = edges[ind];
@@ -1068,7 +1067,7 @@ makeSimpleFlatLabels (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt,
     clip_and_install(e, aghead(e), points, pointn, &sinfo);
     ED_label(e)->pos.x = ctrx;
     ED_label(e)->pos.y = tp.y + (ED_label(e)->dimen.y+LBL_SPACE)/2.0;
-    ED_label(e)->set = TRUE;
+    ED_label(e)->set = true;
 
     miny = tp.y + LBL_SPACE/2.0;
     maxy = miny + ED_label(e)->dimen.y;
@@ -1120,12 +1119,16 @@ makeSimpleFlatLabels (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt,
 	}
 	poly.pn = 8;
 	poly.ps = (Ppoint_t*)points;
-	ps = simpleSplineRoute (tp, hp, poly, &pn, et == ET_PLINE);
-	if (pn == 0) return;
+	pointf *ps = simpleSplineRoute(tp, hp, poly, &pn, et == EDGETYPE_PLINE);
+	if (pn == 0) {
+	    free(ps);
+	    return;
+	}
 	ED_label(e)->pos.x = ctrx;
 	ED_label(e)->pos.y = ctry;
-	ED_label(e)->set = TRUE;
+	ED_label(e)->set = true;
 	clip_and_install(e, aghead(e), ps, pn, &sinfo);
+	free(ps);
     }
 
     /* edges with no labels */
@@ -1172,9 +1175,13 @@ makeSimpleFlatLabels (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt,
 	}
 	poly.pn = 8;
 	poly.ps = (Ppoint_t*)points;
-	ps = simpleSplineRoute (tp, hp, poly, &pn, et == ET_PLINE);
-	if (pn == 0) return;
+	pointf *ps = simpleSplineRoute(tp, hp, poly, &pn, et == EDGETYPE_PLINE);
+	if (pn == 0) {
+	    free(ps);
+	    return;
+	}
 	clip_and_install(e, aghead(e), ps, pn, &sinfo);
+	free(ps);
     }
    
     free (earray);
@@ -1199,13 +1206,13 @@ makeSimpleFlat (node_t* tn, node_t* hn, edge_t** edges, int ind, int cnt, int et
     for (i = 0; i < cnt; i++) {
 	e = edges[ind + i];
 	pointn = 0;
-	if (et == ET_SPLINE || et == ET_LINE) {
+	if (et == EDGETYPE_SPLINE || et == EDGETYPE_LINE) {
 	    points[pointn++] = tp;
 	    points[pointn++] = pointfof((2 * tp.x + hp.x) / 3, dy);
 	    points[pointn++] = pointfof((2 * hp.x + tp.x) / 3, dy);
 	    points[pointn++] = hp;
 	}
-	else {   /* ET_PLINE */
+	else {   /* EDGETYPE_PLINE */
 	    points[pointn++] = tp;
 	    points[pointn++] = tp;
 	    points[pointn++] = pointfof((2 * tp.x + hp.x) / 3, dy);
@@ -1281,7 +1288,7 @@ make_flat_adj_edges(graph_t* g, path* P, edge_t** edges, int ind, int cnt, edge_
     attrs = NEW(attr_state_t);
     auxg = cloneGraph (g, attrs);
     subg = agsubg (auxg, "xxx",1);
-    agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+    agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     agset (subg, "rank", "source");
     rightx = ND_coord(hn).x;
     leftx = ND_coord(tn).x;
@@ -1375,7 +1382,7 @@ make_flat_adj_edges(graph_t* g, path* P, edge_t** edges, int ind, int cnt, edge_
         }
 	if (ED_label(e)) {
 	    ED_label(e)->pos = transformf(ED_label(auxe)->pos, del, GD_flip(g));
-	    ED_label(e)->set = TRUE;
+	    ED_label(e)->set = true;
 	    updateBB(g, ED_label(e));
 	}
     }
@@ -1387,14 +1394,14 @@ make_flat_adj_edges(graph_t* g, path* P, edge_t** edges, int ind, int cnt, edge_
  */
 static void
 makeFlatEnd (graph_t* g, spline_info_t* sp, path* P, node_t* n, edge_t* e, pathend_t* endp,
-             boolean isBegin)
+             bool isBegin)
 {
     boxf b;
 
     b = endp->nb = maximal_bbox(g, sp, n, NULL, e);
     endp->sidemask = TOP;
-    if (isBegin) beginpath(P, e, FLATEDGE, endp, FALSE);
-    else endpath(P, e, FLATEDGE, endp, FALSE);
+    if (isBegin) beginpath(P, e, FLATEDGE, endp, false);
+    else endpath(P, e, FLATEDGE, endp, false);
     b.UR.y = endp->boxes[endp->boxn - 1].UR.y;
     b.LL.y = endp->boxes[endp->boxn - 1].LL.y;
     b = makeregularend(b, TOP, ND_coord(n).y + GD_rank(g)[ND_rank(n)].ht2);
@@ -1405,14 +1412,14 @@ makeFlatEnd (graph_t* g, spline_info_t* sp, path* P, node_t* n, edge_t* e, pathe
  */
 static void
 makeBottomFlatEnd (graph_t* g, spline_info_t* sp, path* P, node_t* n, edge_t* e, 
-	pathend_t* endp, boolean isBegin)
+	pathend_t* endp, bool isBegin)
 {
     boxf b;
 
     b = endp->nb = maximal_bbox(g, sp, n, NULL, e);
     endp->sidemask = BOTTOM;
-    if (isBegin) beginpath(P, e, FLATEDGE, endp, FALSE);
-    else endpath(P, e, FLATEDGE, endp, FALSE);
+    if (isBegin) beginpath(P, e, FLATEDGE, endp, false);
+    else endpath(P, e, FLATEDGE, endp, false);
     b.UR.y = endp->boxes[endp->boxn - 1].UR.y;
     b.LL.y = endp->boxes[endp->boxn - 1].LL.y;
     b = makeregularend(b, BOTTOM, ND_coord(n).y - GD_rank(g)[ND_rank(n)].ht2);
@@ -1428,6 +1435,7 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
 {
     node_t *tn, *hn, *ln;
     pointf *ps;
+    bool ps_needs_free = false;
     pathend_t tend, hend;
     boxf lb;
     int i, pn, ydelta;
@@ -1440,9 +1448,9 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
     for (f = ED_to_virt(e); ED_to_virt(f); f = ED_to_virt(f));
     ln = agtail(f);
     ED_label(e)->pos = ND_coord(ln);
-    ED_label(e)->set = TRUE;
+    ED_label(e)->set = true;
 
-    if (et == ET_LINE) {
+    if (et == EDGETYPE_LINE) {
 	pointf startp, endp, lp;
 
 	startp = add_pointf(ND_coord(tn), ED_tail_port(e).p);
@@ -1465,8 +1473,8 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
 	ydelta /= 6;
 	lb.LL.y = lb.UR.y - MAX(5,ydelta);
 
-	makeFlatEnd (g, sp, P, tn, e, &tend, TRUE);
-	makeFlatEnd (g, sp, P, hn, e, &hend, FALSE);
+	makeFlatEnd (g, sp, P, tn, e, &tend, true);
+	makeFlatEnd (g, sp, P, hn, e, &hend, false);
 
 	boxf boxes[] = {
 	  { .LL = { .x = tend.boxes[tend.boxn - 1].LL.x,
@@ -1483,11 +1491,17 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
 	for (size_t j = 0; j < boxn; j++) add_box(P, boxes[j]);
 	for (i = hend.boxn - 1; i >= 0; i--) add_box(P, hend.boxes[i]);
 
-	if (et == ET_SPLINE) ps = routesplines(P, &pn);
+	ps_needs_free = true;
+	if (et == EDGETYPE_SPLINE) ps = routesplines(P, &pn);
 	else ps = routepolylines(P, &pn);
-	if (pn == 0) return;
+	if (pn == 0) {
+	    free(ps);
+	    return;
+	}
     }
     clip_and_install(e, aghead(e), ps, pn, &sinfo);
+    if (ps_needs_free)
+	free(ps);
 }
 
 /* make_flat_bottom_edges:
@@ -1500,8 +1514,6 @@ make_flat_bottom_edges(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges,
     int j, i, r;
     double stepx, stepy, vspace;
     rank_t* nextr;
-    int pn;
-    pointf *ps;
     pathend_t tend, hend;
 
     tn = agtail(e);
@@ -1518,8 +1530,8 @@ make_flat_bottom_edges(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges,
     stepx = ((double)sp->Multisep) / (cnt + 1); 
     stepy = vspace / (cnt+1);
 
-    makeBottomFlatEnd (g, sp, P, tn, e, &tend, TRUE);
-    makeBottomFlatEnd (g, sp, P, hn, e, &hend, FALSE);
+    makeBottomFlatEnd (g, sp, P, tn, e, &tend, true);
+    makeBottomFlatEnd (g, sp, P, hn, e, &hend, false);
 
     for (i = 0; i < cnt; i++) {
 	boxf b;
@@ -1551,11 +1563,16 @@ make_flat_bottom_edges(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges,
 	for (size_t k = 0; k < boxn; k++) add_box(P, boxes[k]);
 	for (j = hend.boxn - 1; j >= 0; j--) add_box(P, hend.boxes[j]);
 
+	pointf *ps = NULL;
+	int pn = 0;
 	if (splines) ps = routesplines(P, &pn);
 	else ps = routepolylines(P, &pn);
-	if (pn == 0)
+	if (pn == 0) {
+	    free(ps);
 	    return;
+	}
 	clip_and_install(e, aghead(e), ps, pn, &sinfo);
+	free(ps);
 	P->nbox = 0;
     }
 }
@@ -1578,8 +1595,7 @@ make_flat_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int ind
     edge_t *e;
     int j, i, r, isAdjacent;
     double stepx, stepy, vspace;
-    int tside, hside, pn;
-    pointf *ps;
+    int tside, hside;
     pathend_t tend, hend;
 
     fwdedge.out.base.data = (Agrec_t*)&fwdedgei;
@@ -1609,7 +1625,7 @@ make_flat_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int ind
 	return;
     }
 
-    if (et == ET_LINE) {
+    if (et == EDGETYPE_LINE) {
 	makeSimpleFlat (agtail(e), aghead(e), edges, ind, cnt, et);
 	return;
     }
@@ -1618,7 +1634,7 @@ make_flat_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int ind
     hside = ED_head_port(e).side;
     if ((tside == BOTTOM && hside != TOP) ||
         (hside == BOTTOM && tside != TOP)) {
-	make_flat_bottom_edges (g, sp, P, edges, ind, cnt, e, et == ET_SPLINE);
+	make_flat_bottom_edges (g, sp, P, edges, ind, cnt, e, et == EDGETYPE_SPLINE);
 	return;
     }
 
@@ -1639,8 +1655,8 @@ make_flat_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int ind
     stepx = ((double)sp->Multisep) / (cnt+1); 
     stepy = vspace / (cnt+1);
 
-    makeFlatEnd (g, sp, P, tn, e, &tend, TRUE);
-    makeFlatEnd (g, sp, P, hn, e, &hend, FALSE);
+    makeFlatEnd (g, sp, P, tn, e, &tend, true);
+    makeFlatEnd (g, sp, P, hn, e, &hend, false);
 
     for (i = 0; i < cnt; i++) {
 	boxf b;
@@ -1672,11 +1688,16 @@ make_flat_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int ind
 	for (size_t k = 0; k < boxn; k++) add_box(P, boxes[k]);
 	for (j = hend.boxn - 1; j >= 0; j--) add_box(P, hend.boxes[j]);
 
-	if (et == ET_SPLINE) ps = routesplines(P, &pn);
+	pointf *ps = NULL;
+	int pn = 0;
+	if (et == EDGETYPE_SPLINE) ps = routesplines(P, &pn);
 	else ps = routepolylines(P, &pn);
-	if (pn == 0)
+	if (pn == 0) {
+	    free(ps);
 	    return;
+	}
 	clip_and_install(e, aghead(e), ps, pn, &sinfo);
+	free(ps);
 	P->nbox = 0;
     }
 }
@@ -1783,10 +1804,9 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
     Agedgeinfo_t fwdedgeai, fwdedgebi, fwdedgei;
     Agedgepair_t fwdedgea, fwdedgeb, fwdedge;
     edge_t *e, *fe, *le, *segfirst;
-    pointf *ps;
     pathend_t tend, hend;
     boxf b;
-    int sl, si, smode, i, j, dx, pn, hackflag, longedge;
+    int sl, si, smode, i, j, dx, hackflag, longedge;
     static pointf* pointfs;
     static pointf* pointfs2;
     static int numpts;
@@ -1826,7 +1846,7 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	while (ED_to_virt(le))
 	    le = ED_to_virt(le);
 	aghead(&fwdedgea.out) = aghead(le);
-	ED_head_port(&fwdedgea.out).defined = FALSE;
+	ED_head_port(&fwdedgea.out).defined = false;
 	ED_edge_type(&fwdedgea.out) = VIRTUAL;
 	ED_head_port(&fwdedgea.out).p.x = ED_head_port(&fwdedgea.out).p.y = 0;
 	ED_to_orig(&fwdedgea.out) = e;
@@ -1842,10 +1862,10 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 
     /* compute the spline points for the edge */
 
-    if ((et == ET_LINE) && (pointn = makeLineEdge (g, fe, pointfs, &hn))) {
+    if ((et == EDGETYPE_LINE) && (pointn = makeLineEdge (g, fe, pointfs, &hn))) {
     }
     else {
-	bool is_spline = et == ET_SPLINE;
+	bool is_spline = et == EDGETYPE_SPLINE;
 	boxes_t boxes = {0};
 	pointn = 0;
 	segfirst = e;
@@ -1884,20 +1904,23 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	    	       ND_coord(hn).y + GD_rank(g)[ND_rank(hn)].ht2);
 	    if (b.LL.x < b.UR.x && b.LL.y < b.UR.y)
 	        hend.boxes[hend.boxn++] = b;
-	    P->end.theta = M_PI / 2, P->end.constrained = TRUE;
+	    P->end.theta = M_PI / 2, P->end.constrained = true;
 	    assert(boxes.size <= (size_t)INT_MAX && "integer overflow");
 	    completeregularpath(P, segfirst, e, &tend, &hend, boxes.data,
 	                        (int)boxes.size, 1);
+	    pointf *ps = NULL;
+	    int pn = 0;
 	    if (is_spline) ps = routesplines(P, &pn);
 	    else {
 		ps = routepolylines (P, &pn);
-		if ((et == ET_LINE) && (pn > 4)) {
+		if ((et == EDGETYPE_LINE) && (pn > 4)) {
 		    ps[1] = ps[0];
 		    ps[3] = ps[2] = ps[pn-1];
 		    pn = 4;
 		}
 	    }
 	    if (pn == 0) {
+	        free(ps);
 	        boxes_free(&boxes);
 	        return;
 	    }
@@ -1912,6 +1935,7 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	    for (i = 0; i < pn; i++) {
 		pointfs[pointn++] = ps[i];
 	    }
+	    free(ps);
 	    e = straight_path(ND_out(hn).list[0], sl, pointfs, &pointn);
 	    recover_slack(segfirst, P);
 	    segfirst = e;
@@ -1924,12 +1948,13 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	    	       ND_coord(tn).y - GD_rank(g)[ND_rank(tn)].ht1);
 	    if (b.LL.x < b.UR.x && b.LL.y < b.UR.y)
 	        tend.boxes[tend.boxn++] = b;
-	    P->start.theta = -M_PI / 2, P->start.constrained = TRUE;
+	    P->start.theta = -M_PI / 2, P->start.constrained = true;
 	    smode = FALSE;
 	}
 	boxes_append(&boxes, rank_box(sp, g, ND_rank(tn)));
 	b = hend.nb = maximal_bbox(g, sp, hn, e, NULL);
-	endpath(P, hackflag ? &fwdedgeb.out : e, REGULAREDGE, &hend, spline_merge(aghead(e)));
+	endpath(P, hackflag ? &fwdedgeb.out : e, REGULAREDGE, &hend,
+	        spline_merge(aghead(e)));
 	b.UR.y = hend.boxes[hend.boxn - 1].UR.y;
 	b.LL.y = hend.boxes[hend.boxn - 1].LL.y;
 	b = makeregularend(b, TOP,
@@ -1940,9 +1965,11 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	completeregularpath(P, segfirst, e, &tend, &hend, boxes.data, (int)boxes.size,
 	                    longedge);
 	boxes_free(&boxes);
+	pointf *ps = NULL;
+	int pn = 0;
 	if (is_spline) ps = routesplines(P, &pn);
 	else ps = routepolylines (P, &pn);
-	if (et == ET_LINE && pn > 4) {
+	if (et == EDGETYPE_LINE && pn > 4) {
 	    /* Here we have used the polyline case to handle
 	     * an edge between two nodes on adjacent ranks. If the
 	     * results really is a polyline, straighten it.
@@ -1951,8 +1978,10 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	    ps[3] = ps[2] = ps[pn-1];
 	    pn = 4;
         }
-	if (pn == 0)
+	if (pn == 0) {
+	    free(ps);
 	    return;
+	}
 	if (pointn + pn > numpts) {
 	    numpts = 2*(pointn+pn); 
 	    pointfs = RALLOC(numpts, pointfs, pointf);
@@ -1960,6 +1989,7 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
 	for (i = 0; i < pn; i++) {
 	    pointfs[pointn++] = ps[i];
 	}
+	free(ps);
 	recover_slack(segfirst, P);
 	hn = hackflag ? aghead(&fwdedgeb.out) : aghead(e);
     }
@@ -2520,7 +2550,7 @@ neighbor(graph_t* g, node_t *vn, edge_t *ie, edge_t *oe, int dir)
 	    rv = n;
 	    break;
 	}
-	if (pathscross(n, vn, ie, oe) == FALSE) {
+	if (!pathscross(n, vn, ie, oe)) {
 	    rv = n;
 	    break;
 	}
@@ -2528,7 +2558,7 @@ neighbor(graph_t* g, node_t *vn, edge_t *ie, edge_t *oe, int dir)
     return rv;
 }
 
-static boolean pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
+static bool pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
 {
     edge_t *e0, *e1;
     node_t *na, *nb;
@@ -2536,7 +2566,7 @@ static boolean pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
 
     order = ND_order(n0) > ND_order(n1);
     if (ND_out(n0).size != 1 && ND_out(n1).size != 1)
-	return FALSE;
+	return false;
     e1 = oe1;
     if (ND_out(n0).size == 1 && e1) {
 	e0 = ND_out(n0).list[0];
@@ -2544,7 +2574,7 @@ static boolean pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
 	    if ((na = aghead(e0)) == (nb = aghead(e1)))
 		break;
 	    if (order != (ND_order(na) > ND_order(nb)))
-		return TRUE;
+		return true;
 	    if (ND_out(na).size != 1 || ND_node_type(na) == NORMAL)
 		break;
 	    e0 = ND_out(na).list[0];
@@ -2560,7 +2590,7 @@ static boolean pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
 	    if ((na = agtail(e0)) == (nb = agtail(e1)))
 		break;
 	    if (order != (ND_order(na) > ND_order(nb)))
-		return TRUE;
+		return true;
 	    if (ND_in(na).size != 1 || ND_node_type(na) == NORMAL)
 		break;
 	    e0 = ND_in(na).list[0];
@@ -2569,7 +2599,7 @@ static boolean pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
 	    e1 = ND_in(nb).list[0];
 	}
     }
-    return FALSE;
+    return false;
 }
 
 #ifdef DEBUG
