@@ -18,8 +18,10 @@
 
 #include <assert.h>
 #include <cgraph/cgraph.h>
+#include <cgraph/exit.h>
 #include <dotgen/dot.h>
 #include <limits.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -29,7 +31,7 @@
 #define flatindex(v)	ND_low(v)
 
 	/* forward declarations */
-static boolean medians(graph_t * g, int r0, int r1);
+static bool medians(graph_t * g, int r0, int r1);
 static int nodeposcmpf(node_t ** n0, node_t ** n1);
 static int edgeidcmpf(edge_t ** e0, edge_t ** e1);
 static void flat_breakcycles(graph_t * g);
@@ -70,7 +72,7 @@ static graph_t *Root;
 static int GlobalMinRank, GlobalMaxRank;
 static edge_t **TE_list;
 static int *TI_list;
-static boolean ReMincross;
+static bool ReMincross;
 
 #if defined(DEBUG) && DEBUG > 1
 static void indent(graph_t* g)
@@ -233,7 +235,8 @@ getComp (graph_t* g, node_t* n, graph_t* comp, int* indices)
 static void
 fixLabelOrder (graph_t* g, rank_t* rk)
 {
-    int cnt, haveBackedge = FALSE;
+    int cnt;
+    bool haveBackedge = false;
     Agnode_t** arr;
     int* indices;
     Agraph_t* sg;
@@ -245,7 +248,7 @@ fixLabelOrder (graph_t* g, rank_t* rk)
 	v = nxtp = agnxtnode(g, n);
 	for (; v; v = agnxtnode(g, v)) {
 	    if (ND_hi(v) <= ND_lo(n)) { 
-		haveBackedge = TRUE;
+		haveBackedge = true;
 		agedge(g, v, n, NULL, 1);
 	    }
 	    else if (ND_hi(n) <= ND_lo(v)) { 
@@ -304,7 +307,7 @@ checkLabelOrder (graph_t* g)
 		if (!lg) lg = agopen ("lg", Agstrictdirected, 0);
 		snprintf(buf, sizeof(buf), "%d", j);
 		n = agnode(lg, buf, 1);
-		agbindrec(n, "info", sizeof(info_t), 1);
+		agbindrec(n, "info", sizeof(info_t), true);
 		lo = ND_order(aghead(ND_out(u).list[0]));
 		hi = ND_order(aghead(ND_out(u).list[1]));
 		if (lo > hi) {
@@ -373,7 +376,7 @@ void dot_mincross(graph_t * g, int doBalance)
 
     if (GD_n_cluster(g) > 0 && (!(s = agget(g, "remincross")) || mapbool(s))) {
 	mark_lowclusters(g);
-	ReMincross = TRUE;
+	ReMincross = true;
 	nc = mincross(g, 2, 2, doBalance);
 #ifdef DEBUG
 	for (c = 1; c <= GD_n_cluster(g); c++)
@@ -548,7 +551,7 @@ static int left2right(graph_t * g, node_t * v, node_t * w)
     int rv;
 
     /* CLUSTER indicates orig nodes of clusters, and vnodes of skeletons */
-    if (ReMincross == FALSE) {
+    if (!ReMincross) {
 	if (ND_clust(v) != ND_clust(w) && ND_clust(v) && ND_clust(w)) {
 	    /* the following allows cluster skeletons to be swapped */
 	    if (ND_ranktype(v) == CLUSTER && ND_node_type(v) == VIRTUAL)
@@ -556,7 +559,6 @@ static int left2right(graph_t * g, node_t * v, node_t * w)
 	    if (ND_ranktype(w) == CLUSTER && ND_node_type(w) == VIRTUAL)
 		return FALSE;
 	    return TRUE;
-	    /*return ((ND_ranktype(v) != CLUSTER) && (ND_ranktype(w) != CLUSTER)); */
 	}
     } else {
 	if (ND_clust(v) != ND_clust(w))
@@ -726,7 +728,7 @@ static int balance(graph_t * g)
 
     for (r = GD_maxrank(g); r >= GD_minrank(g); r--) {
 
-	GD_rank(g)[r].candidate = FALSE;
+	GD_rank(g)[r].candidate = false;
 	for (i = 0; i < GD_rank(g)[r].n - 1; i++) {
 	    v = GD_rank(g)[r].v[i];
 	    w = GD_rank(g)[r].v[i + 1];
@@ -752,13 +754,13 @@ static int balance(graph_t * g)
     return rv;
 }
 
-static int transpose_step(graph_t * g, int r, int reverse)
+static int transpose_step(graph_t * g, int r, bool reverse)
 {
     int i, c0, c1, rv;
     node_t *v, *w;
 
     rv = 0;
-    GD_rank(g)[r].candidate = FALSE;
+    GD_rank(g)[r].candidate = false;
     for (i = 0; i < GD_rank(g)[r].n - 1; i++) {
 	v = GD_rank(g)[r].v[i];
 	w = GD_rank(g)[r].v[i + 1];
@@ -777,50 +779,41 @@ static int transpose_step(graph_t * g, int r, int reverse)
 	if (c1 < c0 || (c0 > 0 && reverse && c1 == c0)) {
 	    exchange(v, w);
 	    rv += c0 - c1;
-	    GD_rank(Root)[r].valid = FALSE;
-	    GD_rank(g)[r].candidate = TRUE;
+	    GD_rank(Root)[r].valid = false;
+	    GD_rank(g)[r].candidate = true;
 
 	    if (r > GD_minrank(g)) {
-		GD_rank(Root)[r - 1].valid = FALSE;
-		GD_rank(g)[r - 1].candidate = TRUE;
+		GD_rank(Root)[r - 1].valid = false;
+		GD_rank(g)[r - 1].candidate = true;
 	    }
 	    if (r < GD_maxrank(g)) {
-		GD_rank(Root)[r + 1].valid = FALSE;
-		GD_rank(g)[r + 1].candidate = TRUE;
+		GD_rank(Root)[r + 1].valid = false;
+		GD_rank(g)[r + 1].candidate = true;
 	    }
 	}
     }
     return rv;
 }
 
-static void transpose(graph_t * g, int reverse)
+static void transpose(graph_t * g, bool reverse)
 {
     int r, delta;
 
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++)
-	GD_rank(g)[r].candidate = TRUE;
+	GD_rank(g)[r].candidate = true;
     do {
 	delta = 0;
-#ifdef NOTDEF
-	/* don't run both the upward and downward passes- they cancel. 
-	   i tried making it depend on whether an odd or even pass, 
-	   but that didn't help. */
-	for (r = GD_maxrank(g); r >= GD_minrank(g); r--)
-	    if (GD_rank(g)[r].candidate)
-		delta += transpose_step(g, r, reverse);
-#endif
 	for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	    if (GD_rank(g)[r].candidate) {
 		delta += transpose_step(g, r, reverse);
 	    }
 	}
-	/*} while (delta > ncross(g)*(1.0 - Convergence)); */
     } while (delta >= 1);
 }
 
 static int mincross(graph_t * g, int startpass, int endpass, int doBalance)
 {
-    int maxthispass, iter, trying, pass;
+    int maxthispass = 0, iter, trying, pass;
     int cur_cross, best_cross;
 
     if (startpass > 1) {
@@ -887,8 +880,6 @@ static void restore_best(graph_t * g)
     node_t *n;
     int i, r;
 
-    /* for (n = GD_nlist(g); n; n = ND_next(n)) */
-	/* ND_order(n) = saveorder(n); */
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	for (i = 0; i < GD_rank(g)[r].n; i++) {
 	    n = GD_rank(g)[r].v[i];
@@ -896,7 +887,7 @@ static void restore_best(graph_t * g)
 	}
     }
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
-	GD_rank(Root)[r].valid = FALSE;
+	GD_rank(Root)[r].valid = false;
 	qsort(GD_rank(g)[r].v, GD_rank(g)[r].n, sizeof(GD_rank(g)[0].v[0]),
 	      (qsort_cmpf) nodeposcmpf);
     }
@@ -905,8 +896,6 @@ static void restore_best(graph_t * g)
 static void save_best(graph_t * g)
 {
     node_t *n;
-    /* for (n = GD_nlist(g); n; n = ND_next(n)) */
-	/* saveorder(n) = ND_order(n); */
     int i, r;
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	for (i = 0; i < GD_rank(g)[r].n; i++) {
@@ -1145,7 +1134,7 @@ realFillRanks (Agraph_t* g, int rnks[], int rnks_sz, Agraph_t* sg)
 		sg = agsubg (dot_root(g), "_new_rank", 1);
 	    }
 	    n = agnode (sg, NULL, 1);
-	    agbindrec(n, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
+	    agbindrec(n, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);
 	    ND_rank(n) = i;
 	    ND_lw(n) = ND_rw(n) = 0.5;
 	    ND_ht(n) = 1;
@@ -1174,7 +1163,7 @@ static void init_mincross(graph_t * g)
     if (Verbose)
 	start_timer();
 
-    ReMincross = FALSE;
+    ReMincross = false;
     Root = g;
     /* alloc +1 for the null terminator usage in do_ordering() */
     size = agnedges(dot_root(g)) + 1;
@@ -1221,21 +1210,20 @@ static void flat_rev(Agraph_t * g, Agedge_t * e)
 static void flat_search(graph_t * g, node_t * v)
 {
     int i;
-    boolean hascl;
+    bool hascl;
     edge_t *e;
     adjmatrix_t *M = GD_rank(g)[ND_rank(v)].flat;
 
     ND_mark(v) = TRUE;
-    ND_onstack(v) = TRUE;
+    ND_onstack(v) = true;
     hascl = GD_n_cluster(dot_root(g)) > 0;
     if (ND_flat_out(v).list)
 	for (i = 0; (e = ND_flat_out(v).list[i]); i++) {
-	    if (hascl
-		&& NOT(agcontains(g, agtail(e)) && agcontains(g, aghead(e))))
+	    if (hascl && !(agcontains(g, agtail(e)) && agcontains(g, aghead(e))))
 		continue;
 	    if (ED_weight(e) == 0)
 		continue;
-	    if (ND_onstack(aghead(e)) == TRUE) {
+	    if (ND_onstack(aghead(e))) {
 		assert(flatindex(aghead(e)) < M->nrows);
 		assert(flatindex(agtail(e)) < M->ncols);
 		ELT(M, flatindex(aghead(e)), flatindex(agtail(e))) = 1;
@@ -1248,11 +1236,11 @@ static void flat_search(graph_t * g, node_t * v)
 		assert(flatindex(aghead(e)) < M->nrows);
 		assert(flatindex(agtail(e)) < M->ncols);
 		ELT(M, flatindex(agtail(e)), flatindex(aghead(e))) = 1;
-		if (ND_mark(aghead(e)) == FALSE)
+		if (!ND_mark(aghead(e)))
 		    flat_search(g, aghead(e));
 	    }
 	}
-    ND_onstack(v) = FALSE;
+    ND_onstack(v) = false;
 }
 
 static void flat_breakcycles(graph_t * g)
@@ -1264,7 +1252,8 @@ static void flat_breakcycles(graph_t * g)
 	flat = 0;
 	for (i = 0; i < GD_rank(g)[r].n; i++) {
 	    v = GD_rank(g)[r].v[i];
-	    ND_mark(v) = ND_onstack(v) = FALSE;
+	    ND_mark(v) = FALSE;
+	    ND_onstack(v) = false;
 	    flatindex(v) = i;
 	    if (ND_flat_out(v).size > 0 && flat == 0) {
 		GD_rank(g)[r].flat =
@@ -1275,7 +1264,7 @@ static void flat_breakcycles(graph_t * g)
 	if (flat) {
 	    for (i = 0; i < GD_rank(g)[r].n; i++) {
 		v = GD_rank(g)[r].v[i];
-		if (ND_mark(v) == FALSE)
+		if (!ND_mark(v))
 		    flat_search(g, v);
 	    }
 	}
@@ -1380,9 +1369,9 @@ void build_ranks(graph_t * g, int pass)
 	edge_t *e;
 	for (n = GD_nlist(g); n; n = ND_next(n)) {
 	    for (i = 0; (e = ND_out(n).list[i]); i++)
-		assert(MARK(aghead(e)) == FALSE);
+		assert(!MARK(aghead(e)));
 	    for (i = 0; (e = ND_in(n).list[i]); i++)
-		assert(MARK(agtail(e)) == FALSE);
+		assert(!MARK(agtail(e)));
 	}
     }
 #endif
@@ -1394,7 +1383,7 @@ void build_ranks(graph_t * g, int pass)
 	otheredges = pass == 0 ? ND_in(n).list : ND_out(n).list;
 	if (otheredges[0] != NULL)
 	    continue;
-	if (MARK(n) == FALSE) {
+	if (!MARK(n)) {
 	    MARK(n) = TRUE;
 	    enqueue(q, n);
 	    while ((n0 = dequeue(q))) {
@@ -1410,14 +1399,13 @@ void build_ranks(graph_t * g, int pass)
     if (dequeue(q))
 	agerr(AGERR, "surprise\n");
     for (i = GD_minrank(g); i <= GD_maxrank(g); i++) {
-	GD_rank(Root)[i].valid = FALSE;
+	GD_rank(Root)[i].valid = false;
 	if (GD_flip(g) && GD_rank(g)[i].n > 0) {
-	    int n, ndiv2;
 	    node_t **vlist = GD_rank(g)[i].v;
-	    n = GD_rank(g)[i].n - 1;
-	    ndiv2 = n / 2;
-	    for (j = 0; j <= ndiv2; j++)
-		exchange(vlist[j], vlist[n - j]);
+	    int num_nodes_1 = GD_rank(g)[i].n - 1;
+	    int half_num_nodes_1 = num_nodes_1 / 2;
+	    for (j = 0; j <= half_num_nodes_1; j++)
+		exchange(vlist[j], vlist[num_nodes_1 - j]);
 	}
     }
 
@@ -1434,7 +1422,7 @@ void enqueue_neighbors(nodequeue * q, node_t * n0, int pass)
     if (pass == 0) {
 	for (i = 0; i < ND_out(n0).size; i++) {
 	    e = ND_out(n0).list[i];
-	    if ((MARK(aghead(e))) == FALSE) {
+	    if (!MARK(aghead(e))) {
 		MARK(aghead(e)) = TRUE;
 		enqueue(q, aghead(e));
 	    }
@@ -1442,7 +1430,7 @@ void enqueue_neighbors(nodequeue * q, node_t * n0, int pass)
     } else {
 	for (i = 0; i < ND_in(n0).size; i++) {
 	    e = ND_in(n0).list[i];
-	    if ((MARK(agtail(e))) == FALSE) {
+	    if (!MARK(agtail(e))) {
 		MARK(agtail(e)) = TRUE;
 		enqueue(q, agtail(e));
 	    }
@@ -1471,7 +1459,7 @@ static int postorder(graph_t * g, node_t * v, node_t ** list, int r)
     if (ND_flat_out(v).size > 0) {
 	for (i = 0; (e = ND_flat_out(v).list[i]); i++) {
 	    if (!constraining_flat_edge(g,v,e)) continue;
-	    if (MARK(aghead(e)) == FALSE)
+	    if (!MARK(aghead(e)))
 		cnt += postorder(g, aghead(e), list + cnt, r);
 	}
     }
@@ -1487,7 +1475,7 @@ static void flat_reorder(graph_t * g)
     node_t **temprank = NULL;
     edge_t *flat_e, *e;
 
-    if (GD_has_flat_edges(g) == FALSE)
+    if (!GD_has_flat_edges(g))
 	return;
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	if (GD_rank(g)[r].n == 0) continue;
@@ -1514,7 +1502,7 @@ static void flat_reorder(graph_t * g)
 	    if ((local_in_cnt == 0) && (local_out_cnt == 0))
 		temprank[pos++] = v;
 	    else {
-		if ((MARK(v) == FALSE) && (local_in_cnt == 0)) {
+		if (!MARK(v) && local_in_cnt == 0) {
 		    left = temprank + pos;
 		    n_search = postorder(g, v, left, r);
 		    pos += n_search;
@@ -1523,7 +1511,7 @@ static void flat_reorder(graph_t * g)
 	}
 
 	if (pos) {
-	    if (GD_flip(g) == FALSE) {
+	    if (!GD_flip(g)) {
 		left = temprank;
 		right = temprank + pos - 1;
 		while (left < right) {
@@ -1544,9 +1532,9 @@ static void flat_reorder(graph_t * g)
 		v = GD_rank(g)[r].v[i];
 		if (ND_flat_out(v).list) {
 		    for (j = 0; (e = ND_flat_out(v).list[j]); j++) {
-			if ( ((GD_flip(g) == FALSE) && (ND_order(aghead(e)) < ND_order(agtail(e)))) ||
+			if ( (!GD_flip(g) && ND_order(aghead(e)) < ND_order(agtail(e))) ||
 				 ( (GD_flip(g)) && (ND_order(aghead(e)) > ND_order(agtail(e)) ))) {
-			    assert(constraining_flat_edge(g,v,e) == FALSE);
+			    assert(!constraining_flat_edge(g,v,e));
 			    delete_flat_edge(e);
 			    j--;
 			    flat_rev(g, e);
@@ -1557,16 +1545,15 @@ static void flat_reorder(graph_t * g)
 	    /* postprocess to restore intended order */
 	}
 	/* else do no harm! */
-	GD_rank(Root)[r].valid = FALSE;
+	GD_rank(Root)[r].valid = false;
     }
     if (temprank)
 	free(temprank);
 }
 
-static void reorder(graph_t * g, int r, int reverse, int hasfixed)
+static void reorder(graph_t * g, int r, bool reverse, bool hasfixed)
 {
     int changed = 0, nelt;
-    boolean muststay, sawclust;
     node_t **vlist = GD_rank(g)[r].v;
     node_t **lp, **rp, **ep = vlist + GD_rank(g)[r].n;
 
@@ -1579,18 +1566,19 @@ static void reorder(graph_t * g, int r, int reverse, int hasfixed)
 	    if (lp >= ep)
 		break;
 	    /* find the node that can be compared */
-	    sawclust = muststay = FALSE;
+	    bool sawclust = false;
+	    bool muststay = false;
 	    for (rp = lp + 1; rp < ep; rp++) {
 		if (sawclust && ND_clust(*rp))
 		    continue;	/* ### */
 		if (left2right(g, *lp, *rp)) {
-		    muststay = TRUE;
+		    muststay = true;
 		    break;
 		}
 		if (ND_mval(*rp) >= 0)
 		    break;
 		if (ND_clust(*rp))
-		    sawclust = TRUE;	/* ### */
+		    sawclust = true;	/* ### */
 	    }
 	    if (rp >= ep)
 		break;
@@ -1609,21 +1597,17 @@ static void reorder(graph_t * g, int r, int reverse, int hasfixed)
     }
 
     if (changed) {
-	GD_rank(Root)[r].valid = FALSE;
+	GD_rank(Root)[r].valid = false;
 	if (r > 0)
-	    GD_rank(Root)[r - 1].valid = FALSE;
+	    GD_rank(Root)[r - 1].valid = false;
     }
 }
 
 static void mincross_step(graph_t * g, int pass)
 {
     int r, other, first, last, dir;
-    int hasfixed, reverse;
 
-    if (pass % 4 < 2)
-	reverse = TRUE;
-    else
-	reverse = FALSE;
+    bool reverse = pass % 4 < 2;
 
     if (pass % 2 == 0) {	/* down pass */
 	first = GD_minrank(g) + 1;
@@ -1641,10 +1625,10 @@ static void mincross_step(graph_t * g, int pass)
 
     for (r = first; r != last + dir; r += dir) {
 	other = r - dir;
-	hasfixed = medians(g, r, other);
+	bool hasfixed = medians(g, r, other);
 	reorder(g, r, reverse, hasfixed);
     }
-    transpose(g, NOT(reverse));
+    transpose(g, !reverse);
 }
 
 static int local_cross(elist l, int dir)
@@ -1730,7 +1714,7 @@ int ncross(graph_t * g)
 	else {
 	    nc = GD_rank(g)[r].cache_nc = rcross(g, r);
 	    count += nc;
-	    GD_rank(g)[r].valid = TRUE;
+	    GD_rank(g)[r].valid = true;
 	}
     }
     return count;
@@ -1751,7 +1735,7 @@ static int ordercmpf(int *i0, int *i1)
  * a.mval is > 0.
  * Return true if n.mval is left -1, indicating a fixed node for sorting.
  */
-static int flat_mval(node_t * n)
+static bool flat_mval(node_t * n)
 {
     int i;
     edge_t *e, **fl;
@@ -1765,7 +1749,7 @@ static int flat_mval(node_t * n)
 		nn = agtail(e);
 	if (ND_mval(nn) >= 0) {
 	    ND_mval(n) = ND_mval(nn) + 1;
-	    return FALSE;
+	    return false;
 	}
     } else if (ND_flat_out(n).size > 0) {
 	fl = ND_flat_out(n).list;
@@ -1775,20 +1759,20 @@ static int flat_mval(node_t * n)
 		nn = aghead(e);
 	if (ND_mval(nn) > 0) {
 	    ND_mval(n) = ND_mval(nn) - 1;
-	    return FALSE;
+	    return false;
 	}
     }
-    return TRUE;
+    return true;
 }
 
 #define VAL(node,port) (MC_SCALE * ND_order(node) + (port).order)
 
-static boolean medians(graph_t * g, int r0, int r1)
+static bool medians(graph_t * g, int r0, int r1)
 {
     int i, j, j0, lm, rm, lspan, rspan, *list;
     node_t *n, **v;
     edge_t *e;
-    boolean hasfixed = FALSE;
+    bool hasfixed = false;
 
     list = TI_list;
     v = GD_rank(g)[r0].v;
@@ -1886,7 +1870,7 @@ void virtual_weight(edge_t * e)
     assert(t >= 0);
     if (INT_MAX / t < ED_weight(e)) {
 	agerr(AGERR, "overflow when calculating virtual weight of edge\n");
-	exit(EXIT_FAILURE);
+	graphviz_exit(EXIT_FAILURE);
     }
 
     ED_weight(e) *= t;
@@ -1906,7 +1890,7 @@ void check_rs(graph_t * g, int null_ok)
 	    v = GD_rank(g)[r].v[i];
 	    if (v == NULL) {
 		fprintf(stderr, "NULL\t");
-		if (null_ok == FALSE)
+		if (!null_ok)
 		    abort();
 	    } else {
 		fprintf(stderr, "%s(%f)\t", agnameof(v), ND_mval(v));
