@@ -33,6 +33,7 @@
 #include <inttypes.h>
 #include <assert.h>
 #include <fdpgen/tlayout.h>
+#include <math.h>
 #include <neatogen/neatoprocs.h>
 #include <neatogen/adjust.h>
 #include <fdpgen/comp.h>
@@ -40,6 +41,7 @@
 #include <fdpgen/clusteredges.h>
 #include <fdpgen/dbg.h>
 #include <stddef.h>
+#include <stdbool.h>
 
 typedef struct {
     graph_t*  rootg;  /* logical root; graph passed in to fdp_layout */
@@ -181,7 +183,7 @@ static node_t *mkDeriveNode(graph_t * dg, char *name)
     node_t *dn;
 
     dn = agnode(dg, name,1);
-    agbindrec(dn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);	//node custom data
+    agbindrec(dn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);	//node custom data
     ND_alg(dn) = NEW(dndata);	/* free in freeDeriveNode */
     ND_pos(dn) = N_GNEW(GD_ndim(dg), double);
     /* fprintf (stderr, "Creating %s\n", dn->name); */
@@ -344,7 +346,7 @@ static void chkPos(graph_t* g, node_t* n, layout_info* infop, boxf* bbp)
 	if (g != infop->rootg) {
 	    parent =agparent(g);
 	    pp = agxget(parent, G_coord);
-	    if (pp == p || !strcmp(p, pp))
+	    if (!strcmp(p, pp))
 		return;
 	}
 	c = '\0';
@@ -426,7 +428,7 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
     infop->gid++;
 
     dg = agopen("derived", Agstrictdirected,NULL);
-    agbindrec(dg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+    agbindrec(dg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     GD_alg(dg) = NEW(gdata);	/* freed in freeDeriveGraph */
 #ifdef DEBUG
     GORIG(dg) = g;
@@ -501,7 +503,7 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
 		de = agedge(dg, tl, hd, NULL,1);
 	    else
 		de = agedge(dg, hd, tl, NULL,1);
-	    agbindrec(de, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);
+	    agbindrec(de, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
 	    ED_dist(de) = ED_dist(e);
 	    ED_factor(de) = ED_factor(e);
 	    /* fprintf (stderr, "edge %s -- %s\n", tl->name, hd->name); */
@@ -535,7 +537,7 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
 		    de = agedge(dg, m, dn, NULL,1);
 		else
 		    de = agedge(dg, dn, m, NULL,1);
-		agbindrec(de, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);
+		agbindrec(de, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
 		ED_dist(de) = ED_dist(pp->e);
 		ED_factor(de) = ED_factor(pp->e);
 		addEdge(de, pp->e);
@@ -627,9 +629,7 @@ static erec *getEdgeList(node_t * n, graph_t * g)
 		    bnd = M_PI;	/* all values equal up to end */
 		else
 		    bnd = erecs[j].alpha;
-		delta = (bnd - a) / (j - i);
-		if (delta > ANG)
-		    delta = ANG;
+		delta = fmin((bnd - a) / (j - i), ANG);
 		inc = 0;
 		for (; i < j; i++) {
 		    erecs[i].alpha += inc;
@@ -668,10 +668,8 @@ genPorts(node_t * n, erec * er, bport_t * pp, int idx, double bnd)
     else
 	other = aghead(e);
 
-    delta = (bnd - er->alpha) / cnt;
+    delta = fmin((bnd - er->alpha) / cnt, ANG);
     angle = er->alpha;
-    if (delta > ANG)
-	delta = ANG;
 
     if (n < other) {
 	i = idx;
@@ -901,12 +899,12 @@ static int layout(graph_t * g, layout_info * infop)
      * How to combine parts, especially with disparate components?
      */
     if (c_cnt > 1) {
-	boolean *bp;
+	bool *bp;
 	if (pinned) {
-	    bp = N_NEW(c_cnt, boolean);
-	    bp[0] = TRUE;
+	    bp = N_NEW(c_cnt, bool);
+	    bp[0] = true;
 	} else
-	    bp = 0;
+	    bp = NULL;
 	infop->pack.fixed = bp;
 	pts = putGraphs(c_cnt, cc, NULL, &infop->pack);
 	free(bp);
@@ -1012,7 +1010,7 @@ mkClusters (graph_t * g, clist_t* pclist, graph_t* parent)
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg))
 	{
 	if (!strncmp(agnameof(subg), "cluster", 7)) {
-	    agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+	    agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
 	    GD_alg(subg) = NEW(gdata);	/* freed in cleanup_subgs */
 	    GD_ndim(subg) = GD_ndim(parent);
 	    LEVEL(subg) = LEVEL(parent) + 1;
@@ -1033,7 +1031,7 @@ mkClusters (graph_t * g, clist_t* pclist, graph_t* parent)
 
 static void fdp_init_graph(Agraph_t * g)
 {
-    setEdgeType (g, ET_LINE);
+    setEdgeType (g, EDGETYPE_LINE);
     GD_alg(g) = NEW(gdata);	/* freed in cleanup_graph */
     GD_ndim(g) = late_int(g, agattr(g,AGRAPH, "dim", NULL), 2, 2);
     Ndim = GD_ndim(g) = MIN(GD_ndim(g), MAXDIM);
@@ -1070,18 +1068,18 @@ fdpSplines (graph_t * g)
     int trySplines = 0;
     int et = EDGE_TYPE(g);
 
-    if (et > ET_ORTHO) {
-	if (et == ET_COMPOUND) {
-	    trySplines = splineEdges(g, compoundEdges, ET_SPLINE);
+    if (et > EDGETYPE_ORTHO) {
+	if (et == EDGETYPE_COMPOUND) {
+	    trySplines = splineEdges(g, compoundEdges, EDGETYPE_SPLINE);
 	    /* When doing the edges again, accept edges done by compoundEdges */
 	    if (trySplines)
 		Nop = 2;
 	}
-	if (trySplines || et != ET_COMPOUND) {
+	if (trySplines || et != EDGETYPE_COMPOUND) {
 	    if (HAS_CLUST_EDGE(g)) {
 		agerr(AGWARN,
 		      "splines and cluster edges not supported - using line segments\n");
-		et = ET_LINE;
+		et = EDGETYPE_LINE;
 	    } else {
 		spline_edges1(g, et);
 	    }
@@ -1103,7 +1101,7 @@ void fdp_layout(graph_t * g)
     }
     neato_set_aspect(g);
 
-    if (EDGE_TYPE(g) != ET_NONE) fdpSplines (g); 
+    if (EDGE_TYPE(g) != EDGETYPE_NONE) fdpSplines (g);
 
     gv_postprocess(g, 0);
     PSinputscale = save_scale;
