@@ -19,7 +19,6 @@ glCompPanel *glCompPanelNew(glCompObj * parentObj, GLfloat x, GLfloat y,
 			    GLfloat w, GLfloat h)
 {
     glCompPanel *p;
-//      glCompCommon* parent=&parentObj->common;
     p = NEW(glCompPanel);
     glCompInitCommon((glCompObj *) p, parentObj, (GLfloat) x, (GLfloat) y);
 
@@ -35,9 +34,9 @@ glCompPanel *glCompPanelNew(glCompObj * parentObj, GLfloat x, GLfloat y,
     p->common.height = h;
 
     p->common.font = glNewFontFromParent((glCompObj *) p, NULL);
-    p->text = (char *) 0;
+    p->text = NULL;
     p->common.functions.draw = (glcompdrawfunc_t)glCompPanelDraw;
-    p->image = (glCompImage *) 0;
+    p->image = NULL;
     return p;
 }
 void glCompSetPanelText(glCompPanel * p, char *t)
@@ -59,56 +58,44 @@ int glCompPanelDraw(glCompObj * o)
     ref = p->common;
     glCompCalcWidget((glCompCommon *) p->common.parent, &p->common, &ref);
     p->objType = glPanelObj;
-    //typedef enum {glPanelObj,glbuttonObj,glLabelObj,glImageObj}glObjType;
-
 
     if (!p->common.visible)
 	return 0;
     /*draw shadow */
-    glColor4f((GLfloat) p->shadowcolor.R, (GLfloat) p->shadowcolor.G,
-	      (GLfloat) p->shadowcolor.B, (GLfloat) p->shadowcolor.A);
+    glColor4f(p->shadowcolor.R, p->shadowcolor.G, p->shadowcolor.B,
+              p->shadowcolor.A);
     r.h = p->shadowwidth;
     r.w = ref.width;
     r.pos.x = ref.pos.x + p->shadowwidth;
     r.pos.y = ref.pos.y - p->shadowwidth;
-    r.pos.z = -0.001;
+    r.pos.z = -0.001f;
     glCompDrawRectangle(&r);
     r.h = ref.height;
     r.w = p->shadowwidth;
     r.pos.x = ref.pos.x + ref.width;
     r.pos.y = ref.pos.y - p->shadowwidth;
-    r.pos.z = -0.001;
+    r.pos.z = -0.001f;
     glCompDrawRectangle(&r);
     /*draw panel */
-    glCompDrawRectPrism(&(ref.pos), ref.width, ref.height,
-			p->common.borderWidth, 0.01, &(ref.color), 1);
+    glCompDrawRectPrism(&ref.pos, ref.width, ref.height,
+			p->common.borderWidth, 0.01f, &ref.color, 1);
     /*draw image if there is */
     if (p->image) {
 	p->image->common.callbacks.draw((void *) p->image);
-    }
-    if (p->text) {
-
-
     }
     return 1;
 }
 
-
 int glCompPanelHide(glCompPanel * p)
 {
-    /* int ind = 0; */
     p->common.visible = 0;
     return 1;
-
-
 }
 
 int glCompPanelShow(glCompPanel * p)
 {
-    /* int ind = 0; */
     p->common.visible = 1;
     return 1;
-
 }
 
 void glCompPanelClick(glCompObj * o, GLfloat x, GLfloat y,
@@ -162,12 +149,3 @@ void glCompPanelMouseUp(glCompObj * obj, GLfloat x, GLfloat y,
     if (((glCompPanel *) obj)->common.callbacks.mouseup)
 	((glCompPanel *) obj)->common.callbacks.mouseup(obj, x, y, t);
 }
-
-
-#if 0
-
-void glCompPanelSetText(glCompPanel * p, char *str)
-{
-//    replacestr(str, &p->text);
-}
-#endif
