@@ -43,9 +43,6 @@ static int glob (GVC_t * gvc, char*, int, int (*errfunc)(const char *, int), glo
 #include	<glob.h>
 #endif 
 #include	<sys/stat.h>
-#ifdef HAVE_UNISTD_H
-#include	<unistd.h>
-#endif
 #endif
 
 #ifdef __APPLE__
@@ -337,7 +334,9 @@ char * gvconfig_libdir(GVC_t * gvc)
 			libdir = line;
 		    else
 		        libdir = gmalloc(len);
-		    bcopy(p, libdir, ind);
+		    if (ind > 0) {
+		        memmove(libdir, p, ind);
+		    }
 		    /* plugins are in "graphviz" subdirectory */
 		    strcpy(libdir+ind, "/graphviz");  
 		    break;
