@@ -56,8 +56,22 @@ Agraph_t *sameG(void *p1, void *p2, char *fn, char *msg)
  */
 int indexOf(char *s1, char *s2)
 {
-    char *s = strstr(s1, s2);
-    return s == NULL ? -1 : (int)(s1 - s);
+    char c1 = *s2;
+    char c;
+    char *p;
+    int len2;
+
+    if (c1 == '\0')
+	return 0;
+    p = s1;
+    len2 = strlen(s2) - 1;
+    while ((c = *p++)) {
+	if (c != c1)
+	    continue;
+	if (strncmp(p, s2 + 1, len2) == 0)
+	    return ((p - s1) - 1);
+    }
+    return -1;
 }
 
 /* rindexOf:
@@ -1277,6 +1291,7 @@ char *colorx (Expr_t* ex, char* incolor, char* fmt, Sfio_t* fp)
     }
     else if (*fmt == 'C') {
 	type = CMYK_BYTE;
+	alpha = 0;
     }
     else
 	return "";
