@@ -15,17 +15,18 @@
 #include <common/memory.h>
 #include <neatogen/delaunay.h>
 #include <stddef.h>
+#include <stdbool.h>
 
-SparseMatrix call_tri(int n, int dim, real * x)
+SparseMatrix call_tri(int n, int dim, double * x)
 {
-    real one = 1;
+    double one = 1;
     int i, ii, jj;
     SparseMatrix A;
     SparseMatrix B;
     int* edgelist = NULL;
-    real* xv = N_GNEW(n, real);
-    real* yv = N_GNEW(n, real);
-    int numberofedges;
+    double* xv = N_GNEW(n, double);
+    double* yv = N_GNEW(n, double);
+    int numberofedges = 0;
 
     for (i = 0; i < n; i++) {
 	xv[i] = x[i * 2];
@@ -34,27 +35,25 @@ SparseMatrix call_tri(int n, int dim, real * x)
 
     if (n > 2) {
 	edgelist = delaunay_tri (xv, yv, n, &numberofedges);
-    } else {
-	numberofedges = 0;
     }
 
     A = SparseMatrix_new(n, n, 1, MATRIX_TYPE_REAL, FORMAT_COORD);
     for (i = 0; i < numberofedges; i++) {
 	ii = edgelist[i * 2];
 	jj = edgelist[i * 2 + 1];
-	SparseMatrix_coordinate_form_add_entries(A, 1, &(ii), &(jj), &one);
+	SparseMatrix_coordinate_form_add_entry(A, ii, jj, &one);
     }
     if (n == 2) {		/* if two points, add edge i->j */
 	ii = 0;
 	jj = 1;
-	SparseMatrix_coordinate_form_add_entries(A, 1, &(ii), &(jj), &one);
+	SparseMatrix_coordinate_form_add_entry(A, ii, jj, &one);
     }
     for (i = 0; i < n; i++) {
-	SparseMatrix_coordinate_form_add_entries(A, 1, &i, &i, &one);
+	SparseMatrix_coordinate_form_add_entry(A, i, i, &one);
     }
     B = SparseMatrix_from_coordinate_format(A);
     SparseMatrix_delete(A);
-    A = SparseMatrix_symmetrize(B, FALSE);
+    A = SparseMatrix_symmetrize(B, false);
     SparseMatrix_delete(B);
     B = A;
 
@@ -64,16 +63,16 @@ SparseMatrix call_tri(int n, int dim, real * x)
     return B;
 }
 
-SparseMatrix call_tri2(int n, int dim, real * xx)
+SparseMatrix call_tri2(int n, int dim, double * xx)
 {
-    real *x, *y;
+    double *x, *y;
     v_data *delaunay;
     int i, j;
     SparseMatrix A;
     SparseMatrix B;
-    real one = 1;
-    x = N_GNEW(n, real);
-    y = N_GNEW(n, real);
+    double one = 1;
+    x = N_GNEW(n, double);
+    y = N_GNEW(n, double);
 
     for (i = 0; i < n; i++) {
 	x[i] = xx[dim * i];
@@ -86,16 +85,14 @@ SparseMatrix call_tri2(int n, int dim, real * xx)
 
     for (i = 0; i < n; i++) {
 	for (j = 1; j < delaunay[i].nedges; j++) {
-	    SparseMatrix_coordinate_form_add_entries(A, 1, &i,
-						     &(delaunay[i].
-						       edges[j]), &one);
+	    SparseMatrix_coordinate_form_add_entry(A, i, delaunay[i].edges[j], &one);
 	}
     }
     for (i = 0; i < n; i++) {
-	SparseMatrix_coordinate_form_add_entries(A, 1, &i, &i, &one);
+	SparseMatrix_coordinate_form_add_entry(A, i, i, &one);
     }
     B = SparseMatrix_from_coordinate_format(A);
-    B = SparseMatrix_symmetrize(B, FALSE);
+    B = SparseMatrix_symmetrize(B, false);
     SparseMatrix_delete(A);
 
     free (x);
