@@ -648,67 +648,60 @@ segCmp (segment* S1, segment* S2, bend T1, bend T2)
     if(S1->p.p1<S2->p.p1&&S2->p.p1<S1->p.p2)
 	return overlapSeg (S1, S2, T1, T2);
 	/* left endpoint of S1 inside S2 */
-    else if(S2->p.p1<S1->p.p1&&S1->p.p1<S2->p.p2)
+    if (S2->p.p1 < S1->p.p1 && S1->p.p1 < S2->p.p2)
 	return -1*overlapSeg (S2, S1, T1, T2);
-    else if(S1->p.p1==S2->p.p1) {
+    if (S1->p.p1 == S2->p.p1) {
 	if(S1->p.p2==S2->p.p2) {
 	    if (S1->l1 == S2->l1 && S1->l2 == S2->l2)
 		return 0;
-	    else if (S2->l1==S2->l2) {
+	    if (S2->l1 == S2->l2) {
 		if (S2->l1 == T1) return 1;
-		else if (S2->l1 == T2) return -1;
-		else if (S1->l1 != T1 && S1->l2 != T1) return 1;
-		else if (S1->l1 != T2 && S1->l2 != T2) return -1;
-		else return 0;
+		if (S2->l1 == T2) return -1;
+		if (S1->l1 != T1 && S1->l2 != T1) return 1;
+		if (S1->l1 != T2 && S1->l2 != T2) return -1;
+		return 0;
 	    }
-	    else if (S2->l1 == T1 && S2->l2 == T2) {
+	    if (S2->l1 == T1 && S2->l2 == T2) {
 		if (S1->l1 != T1 && S1->l2 == T2) return 1;
-		else if (S1->l1 == T1 && S1->l2 != T2) return -1;
-		else return 0;
+		if (S1->l1 == T1 && S1->l2 != T2) return -1;
+		return 0;
 	    }
-	    else if (S2->l2 == T1 && S2->l1 == T2) {
+	    if (S2->l2 == T1 && S2->l1 == T2) {
 		if (S1->l2 != T1 && S1->l1 == T2) return 1;
-		else if (S1->l2 == T1 && S1->l1 != T2) return -1;
-		else return 0;
+		if (S1->l2 == T1 && S1->l1 != T2) return -1;
+		return 0;
 	    }
-	    else if (S2->l1 == B_NODE && S2->l2 == T1) {
+	    if (S2->l1 == B_NODE && S2->l2 == T1) {
 		return ellSeg (S1->l1, S1->l2, T1);
 	    }
-	    else if (S2->l1 == B_NODE && S2->l2 == T2) {
+	    if (S2->l1 == B_NODE && S2->l2 == T2) {
 		return -1*ellSeg (S1->l1, S1->l2, T2);
 	    }
-	    else if (S2->l1 == T1 && S2->l2 == B_NODE) {
+	    if (S2->l1 == T1 && S2->l2 == B_NODE) {
 		return ellSeg (S1->l2, S1->l1, T1);
 	    }
-	    else { /* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
-		return -1*ellSeg (S1->l2, S1->l1, T2);
-	    }
+	    /* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
+	    return -1 * ellSeg(S1->l2, S1->l1, T2);
 	}
-	else if(S1->p.p2<S2->p.p2) {
+	if (S1->p.p2 < S2->p.p2) {
 	    if(S1->l2==T1)
 		return eqEndSeg (S2->l1, S1->l1, T1, T2);
-	    else
-		return -1*eqEndSeg (S2->l1, S1->l1, T1, T2);
-	}
-	else { /* S1->p.p2>S2->p.p2 */
-	    if(S2->l2==T2)
-		return eqEndSeg (S1->l1, S2->l1, T1, T2);
-	    else
-		return -1*eqEndSeg (S1->l1, S2->l1, T1, T2);
+	    return -1 * eqEndSeg(S2->l1, S1->l1, T1, T2);
 	}
+	/* S1->p.p2>S2->p.p2 */
+	if (S2->l2 == T2)
+	    return eqEndSeg(S1->l1, S2->l1, T1, T2);
+	return -1 * eqEndSeg(S1->l1, S2->l1, T1, T2);
     }
-    else if(S1->p.p2==S2->p.p1) {
+    if (S1->p.p2 == S2->p.p1) {
 	if (S1->l2 == S2->l1) return 0;
-	else if (S1->l2 == T2) return 1;
-	else return -1;
+	if (S1->l2 == T2) return 1;
+	return -1;
     }
-    else { /* S1->p.p1==S2->p.p2 */
-	if (S1->l1 == S2->l2) return 0;
-	else if (S1->l1 == T2) return 1;
-	else return -1;
-    }
-    assert(0);
-    return 0;
+    /* S1->p.p1==S2->p.p2 */
+    if (S1->l1 == S2->l2) return 0;
+    if (S1->l1 == T2) return 1;
+    return -1;
 }
 
 /* Function seg_cmp returns
@@ -1205,7 +1198,7 @@ attachOrthoEdges(maze* mp, size_t n_edges, route* route_list, splineInfo *sinfo,
 	    fprintf(stderr, "ortho %s %s\n", agnameof(agtail(e)),agnameof(aghead(e)));
 	clip_and_install(e, aghead(e), ispline, npts, sinfo);
 	if (doLbls && (lbl = ED_label(e)) && !lbl->set)
-	    addEdgeLabels(e, p1, q1);
+	    addEdgeLabels(e);
     }
     free(ispline);
 }
@@ -1294,7 +1287,7 @@ orthoEdges (Agraph_t* g, int doLbls)
 	agerr(AGWARN, "Orthogonal edges do not currently handle edge labels. Try using xlabels.\n");
 	doLbls = 0;
     }
-    mp = mkMaze (g, doLbls);
+    mp = mkMaze(g);
     sg = mp->sg;
 #ifdef DEBUG
     if (odb_flags & ODB_SGRAPH) emitSearchGraph (stderr, sg);
@@ -1498,6 +1491,16 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
     return bb;
 }
 
+/**
+ * @brief dumps in dot format @ref cells and @ref edges of
+ * @ref sgraph for debugging
+ *
+ * The routine uses coordinates of @ref cells calculated
+ * from @ref gcells.
+ * Coordinates of @ref gcellg are calculated by original
+ * specified graph layout engine.
+ */
+
 static void
 emitSearchGraph (FILE* fp, sgraph* sg)
 {
@@ -1508,6 +1511,7 @@ emitSearchGraph (FILE* fp, sgraph* sg)
     int i;
     fputs ("graph G {\n", fp);
     fputs (" node[shape=point]\n", fp);
+    fputs (" layout=neato\n", fp);
     for (i = 0; i < sg->nnodes; i++) {
 	np = sg->nodes+i;
 	cp = np->cells[0];
@@ -1520,11 +1524,11 @@ emitSearchGraph (FILE* fp, sgraph* sg)
 	    if (IsNode(cp)) cp = np->cells[1];
 	    p = coordOf (cp, np);
 	}
-	fprintf (fp, "  %d [pos=\"%d,%d\"]\n", i, p.x, p.y);
+	fprintf (fp, "  %d [pos=\"%d,%d!\"]\n", i, p.x, p.y);
     }
     for (i = 0; i < sg->nedges; i++) {
 	ep = sg->edges+i;
-	fprintf (fp, "  %d -- %d[len=\"%f\"]\n", ep->v1, ep->v2, ep->weight);
+	fprintf (fp, "  %d -- %d[label=\"%f\"]\n", ep->v1, ep->v2, ep->weight);
     }
     fputs ("}\n", fp);
 }
