@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /* 
@@ -19,8 +16,8 @@
  */
 
 #include <stdlib.h>
-#include "vispath.h"
-#include "pathutil.h"
+#include <pathplan/vispath.h>
+#include <pathplan/pathutil.h>
 
 int in_poly(Ppoly_t poly, Ppoint_t q)
 {
