@@ -989,17 +989,17 @@ void SpringSmoother_delete(SpringSmoother sm){
 
 
 
-void SpringSmoother_smooth(SpringSmoother sm, SparseMatrix A, double *node_weights, int dim, double *x){
+void SpringSmoother_smooth(SpringSmoother sm, SparseMatrix A, int dim, double *x){
   int flag = 0;
 
-  spring_electrical_spring_embedding(dim, A, sm->D, sm->ctrl, node_weights, x, &flag);
+  spring_electrical_spring_embedding(dim, A, sm->D, sm->ctrl, x, &flag);
   assert(!flag);
 
 }
 
 /*=============================== end of spring and spring-electrical based smoother =========== */
 
-void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control ctrl, double *node_weights, double *x, int *flag){
+void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control ctrl, double *x, int *flag){
 #ifdef TIME
   clock_t  cpu;
 #endif
@@ -1053,7 +1053,7 @@ void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control c
 
     for (k = 0; k < 1; k++){
       sm = SpringSmoother_new(A, dim, ctrl, x);
-      SpringSmoother_smooth(sm, A, node_weights, dim, x);
+      SpringSmoother_smooth(sm, A, dim, x);
       SpringSmoother_delete(sm);
     }
 
