@@ -22,10 +22,11 @@
 #include <sfdpgen/uniform_stress.h>
 #include <sfdpgen/stress_model.h>
 #include <cgraph/strcasecmp.h>
+#include <stdbool.h>
 
 static void sfdp_init_edge(edge_t * e)
 {
-    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);	//node custom data
+    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);	//node custom data
     common_init_edge(e);
 }
 
@@ -33,17 +34,9 @@ static void sfdp_init_node_edge(graph_t * g)
 {
     node_t *n;
     edge_t *e;
-#if 0
-    int nnodes = agnnodes(g);
-    attrsym_t *N_pos = agfindnodeattr(g, "pos");
-#endif
 
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	neato_init_node(n);
-#if 0
-   FIX so that user positions works with multiscale
-	user_pos(N_pos, NULL, n, nnodes); 
-#endif
     }
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e))
@@ -55,7 +48,7 @@ static void sfdp_init_graph(Agraph_t * g)
 {
     int outdim;
 
-    setEdgeType(g, ET_LINE);
+    setEdgeType(g, EDGETYPE_LINE);
     outdim = late_int(g, agfindgraphattr(g, "dimen"), 2, 2);
     GD_ndim(agroot(g)) = late_int(g, agfindgraphattr(g, "dim"), outdim, 2);
     Ndim = GD_ndim(agroot(g)) = MIN(GD_ndim(agroot(g)), MAXDIM);
@@ -65,10 +58,10 @@ static void sfdp_init_graph(Agraph_t * g)
 
 /* getPos:
  */
-static real *getPos(Agraph_t * g, spring_electrical_control ctrl)
+static double *getPos(Agraph_t * g)
 {
     Agnode_t *n;
-    real *pos = N_NEW(Ndim * agnnodes(g), real);
+    double *pos = N_NEW(Ndim * agnnodes(g), double);
     int ix, i;
 
     if (agfindnodeattr(g, "pos") == NULL)
@@ -89,8 +82,8 @@ static real *getPos(Agraph_t * g, spring_electrical_control ctrl)
 static void sfdpLayout(graph_t * g, spring_electrical_control ctrl,
 		       int hops, pointf pad)
 {
-    real *sizes;
-    real *pos;
+    double *sizes;
+    double *pos;
     Agnode_t *n;
     int flag, i;
     int n_edge_label_nodes = 0, *edge_label_nodes = NULL;
@@ -110,26 +103,26 @@ static void sfdpLayout(graph_t * g, spring_electrical_control ctrl,
     }
     else
 	sizes = NULL;
-    pos = getPos(g, ctrl);
+    pos = getPos(g);
 
     switch (ctrl->method) {
     case METHOD_SPRING_ELECTRICAL:
     case METHOD_SPRING_MAXENT:
-	multilevel_spring_electrical_embedding(Ndim, A, D, ctrl, NULL, sizes, pos, n_edge_label_nodes, edge_label_nodes, &flag);
+	multilevel_spring_electrical_embedding(Ndim, A, D, ctrl, sizes, pos, n_edge_label_nodes, edge_label_nodes, &flag);
 	break;
     case METHOD_UNIFORM_STRESS:
 	uniform_stress(Ndim, A, pos, &flag);
 	break;
     case METHOD_STRESS:{
 	int maxit = 200;
-	real tol = 0.001;
+	double tol = 0.001;
 	int weighted = TRUE;
 
 	if (!D){
 	    D = SparseMatrix_get_real_adjacency_matrix_symmetrized(A);/* all distance 1 */
 	    weighted = FALSE;
 	} else {
-	    D = SparseMatrix_symmetrize_nodiag(D, FALSE);
+	    D = SparseMatrix_symmetrize_nodiag(D);
 	    weighted = TRUE;
 	}
 	if (hops > 0){
@@ -149,7 +142,7 @@ static void sfdpLayout(graph_t * g, spring_electrical_control ctrl,
     }
 
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	real *npos = pos + (Ndim * ND_id(n));
+	double *npos = pos + (Ndim * ND_id(n));
 	for (i = 0; i < Ndim; i++) {
 	    ND_pos(n)[i] = npos[i];
 	}
@@ -159,45 +152,9 @@ static void sfdpLayout(graph_t * g, spring_electrical_control ctrl,
     free(pos);
     SparseMatrix_delete (A);
     if (D) SparseMatrix_delete (D);
-    if (edge_label_nodes) FREE(edge_label_nodes);
+    free(edge_label_nodes);
 }
 
-#if UNUSED
-static int
-late_mode (graph_t* g, Agsym_t* sym, int dflt)
-{
-    char* s;
-    int v;
-    int rv;
-
-    if (!sym) return dflt;
-    s = agxget (g, sym);
-    if (isdigit(*s)) {
-	if ((v = atoi (s)) <= METHOD_UNIFORM_STRESS)
-	    rv = v;
-	else
-	    rv = dflt;
-    }
-    else if (isalpha(*s)) {
-	if (!strcasecmp(s, "spring"))
-	    rv = METHOD_SPRING_ELECTRICAL;
-	else if (!strcasecmp(s, "maxent"))
-	    rv = METHOD_SPRING_MAXENT;
-	else if (!strcasecmp(s, "stress"))
-	    rv = METHOD_STRESS;
-	else if (!strcasecmp(s, "uniform"))
-	    rv = METHOD_UNIFORM_STRESS;
-	else {
-	    agerr (AGWARN, "Unknown value \"%s\" for mode attribute\n", s);
-	    rv = dflt;
-	}
-    }
-    else
-	rv = dflt;
-    return rv;
-}
-#endif
-
 static int
 late_smooth (graph_t* g, Agsym_t* sym, int dflt)
 {
@@ -207,8 +164,8 @@ late_smooth (graph_t* g, Agsym_t* sym, int dflt)
 
     if (!sym) return dflt;
     s = agxget (g, sym);
-    if (isdigit(*s)) {
-#if (HAVE_GTS || HAVE_TRIANGLE)
+    if (isdigit((int)*s)) {
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	if ((v = atoi (s)) <= SMOOTHING_RNG)
 #else
 	if ((v = atoi (s)) <= SMOOTHING_SPRING)
@@ -217,7 +174,7 @@ late_smooth (graph_t* g, Agsym_t* sym, int dflt)
 	else
 	    rv = dflt;
     }
-    else if (isalpha(*s)) {
+    else if (isalpha((int)*s)) {
 	if (!strcasecmp(s, "avg_dist"))
 	    rv = SMOOTHING_STRESS_MAJORIZATION_AVG_DIST;
 	else if (!strcasecmp(s, "graph_dist"))
@@ -226,13 +183,13 @@ late_smooth (graph_t* g, Agsym_t* sym, int dflt)
 	    rv = SMOOTHING_NONE;
 	else if (!strcasecmp(s, "power_dist"))
 	    rv = SMOOTHING_STRESS_MAJORIZATION_POWER_DIST;
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	else if (!strcasecmp(s, "rng"))
 	    rv = SMOOTHING_RNG;
 #endif
 	else if (!strcasecmp(s, "spring"))
 	    rv = SMOOTHING_SPRING;
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	else if (!strcasecmp(s, "triangle"))
 	    rv = SMOOTHING_TRIANGLE;
 #endif
@@ -253,13 +210,13 @@ late_quadtree_scheme (graph_t* g, Agsym_t* sym, int dflt)
 
     if (!sym) return dflt;
     s = agxget (g, sym);
-    if (isdigit(*s)) {
+    if (isdigit((int)*s)) {
       if ((v = atoi (s)) <= QUAD_TREE_FAST && v >= QUAD_TREE_NONE){
 	rv = v;
       }	else {
 	rv = dflt;
       }
-    } else if (isalpha(*s)) {
+    } else if (isalpha((int)*s)) {
       if (!strcasecmp(s, "none") || !strcasecmp(s, "false") ){
 	rv = QUAD_TREE_NONE;
       } else if (!strcasecmp(s, "normal") || !strcasecmp(s, "true") || !strcasecmp(s, "yes")){
@@ -278,9 +235,6 @@ late_quadtree_scheme (graph_t* g, Agsym_t* sym, int dflt)
 
 /* tuneControl:
  * Use user values to reset control
- * 
- * Possible parameters:
- *   ctrl->use_node_weights
  */
 static void
 tuneControl (graph_t* g, spring_electrical_control ctrl)
@@ -300,10 +254,9 @@ tuneControl (graph_t* g, spring_electrical_control ctrl)
     ctrl->multilevels = late_int(g, agfindgraphattr(g, "levels"), INT_MAX, 0);
     ctrl->smoothing = late_smooth(g, agfindgraphattr(g, "smoothing"), SMOOTHING_NONE);
     ctrl->tscheme = late_quadtree_scheme(g, agfindgraphattr(g, "quadtree"), QUAD_TREE_NORMAL);
-    /* ctrl->method = late_mode(g, agfindgraphattr(g, "mode"), METHOD_SPRING_ELECTRICAL); */
     ctrl->method = METHOD_SPRING_ELECTRICAL;
-    ctrl->beautify_leaves = mapBool (agget(g, "beautify"), FALSE);
-    ctrl->do_shrinking = mapBool (agget(g, "overlap_shrink"), TRUE);
+    ctrl->beautify_leaves = mapBool(agget(g, "beautify"), false) ? TRUE : FALSE;
+    ctrl->do_shrinking = mapBool(agget(g, "overlap_shrink"), true) ? TRUE : FALSE;
     ctrl->rotation = late_double(g, agfindgraphattr(g, "rotation"), 0.0, -MAXDOUBLE);
     ctrl->edge_labeling_scheme = late_int(g, agfindgraphattr(g, "label_scheme"), 0, 0);
     if (ctrl->edge_labeling_scheme > 4) {
@@ -330,7 +283,7 @@ void sfdp_layout(graph_t * g)
 	spring_electrical_control ctrl = spring_electrical_control_new();
 
 	tuneControl (g, ctrl);
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	graphAdjustMode(g, &am, "prism0");
 #else
 	graphAdjustMode(g, &am, 0);
@@ -372,7 +325,7 @@ void sfdp_layout(graph_t * g)
 		nodeInduce(sg);
 		sfdpLayout(sg, ctrl, hops, pad);
 		if (doAdjust) removeOverlapWith(sg, &am);
-		setEdgeType(sg, ET_LINE);
+		setEdgeType(sg, EDGETYPE_LINE);
 		spline_edges(sg);
 	    }
 	    packSubgraphs(ncc, ccs, g, &pinfo);
@@ -387,10 +340,6 @@ void sfdp_layout(graph_t * g)
     dotneato_postprocess(g);
 }
 
-static void sfdp_cleanup_graph(graph_t * g)
-{
-}
-
 void sfdp_cleanup(graph_t * g)
 {
     node_t *n;
@@ -402,6 +351,5 @@ void sfdp_cleanup(graph_t * g)
 	}
 	gv_cleanup_node(n);
     }
-    sfdp_cleanup_graph(g);
 }
  
