@@ -1,5 +1,3 @@
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -7,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 ///////////////////////////////////////
@@ -29,11 +27,10 @@
 #include <string.h>
 #include <math.h>
 #include <time.h>
-#include "matrix_ops.h"
-/* #include "hierarchy.h" */
-#include "delaunay.h"
-#include "memory.h"
-#include "arith.h"
+#include <neatogen/matrix_ops.h>
+#include <neatogen/delaunay.h>
+#include <common/memory.h>
+#include <common/arith.h>
 
 static double *compute_densities(v_data * graph, int n, double *x,
 				 double *y)
@@ -47,9 +44,7 @@ static double *compute_densities(v_data * graph, int n, double *x,
 	sum = 0;
 	for (j = 1; j < graph[i].nedges; j++) {
 	    neighbor = graph[i].edges[j];
-	    sum +=
-		sqrt((x[i] - x[neighbor]) * (x[i] - x[neighbor]) +
-		     (y[i] - y[neighbor]) * (y[i] - y[neighbor]));
+	    sum += hypot(x[i] - x[neighbor], y[i] - y[neighbor]);
 	}
 	densities[i] = sum / graph[i].nedges;
     }
@@ -194,7 +189,7 @@ static void
 rescaleLayout(v_data * graph, int n, double *x_coords, double *y_coords,
 	      int interval, double distortion)
 {
-    // Rectlinear distortion - auxilliary function
+    // Rectlinear distortion - auxiliary function
     int i;
     double *densities = NULL, *smoothed_densities = NULL;
     double *copy_coords = N_NEW(n, double);
@@ -320,14 +315,14 @@ rescale_layout(double *x_coords, double *y_coords,
     }
 }
 
-#define DIST(x1,y1,x2,y2) (sqrt((x1-x2)*(x1-x2)+(y1-y2)*(y1-y2)))
+#define DIST(x1, y1, x2, y2) hypot((x1) - (x2), (y1) - (y2))
 
 static void
 rescale_layout_polarFocus(v_data * graph, int n,
 	  double *x_coords, double *y_coords,
 	  double x_focus, double y_focus, int interval, double distortion)
 {
-    // Polar distortion - auxilliary function
+    // Polar distortion - auxiliary function
     int i;
     double *densities = NULL, *smoothed_densities = NULL;
     double *distances = N_NEW(n, double);
